
// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>
#include <sbkpep.h>
#include <sbkpepbuffer.h>

#define PYSIDE6_COMOPT_COMPRESS 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqobject.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include <pysideqenum.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "akonadicore_python.h"

// main header
#include "akonadi_entitytreemodel_wrapper.h"

// Wrappers providing overrides
#include "akonadi_trashfilterproxymodel_wrapper.h"

// Argument includes
#include <QHash>
#include <QList>
#include <QMap>
#include <QString>
#include <QStringList>
#include <collection.h>
#include <collectionfetchscope.h>
#include <entitytreemodel.h>
#include <item.h>
#include <monitor.h>
#include <qabstractitemmodel.h>
#include <qbytearray.h>
#include <qmetaobject.h>
#include <qnamespace.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qsize.h>
#include <qvariant.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

using namespace Akonadi;

extern "C" {
static PyTypeObject *Sbk_Akonadi_EntityTreeModel_TypeF(void)
{
    return SbkAkonadiCoreTypeStructs[SBK_Akonadi_EntityTreeModel_IDX].type;
}
} // extern "C"

// Native ---------------------------------------------------------

void EntityTreeModelWrapper::resetPyMethodCache()
{
    std::fill(m_PyMethodCache.begin(), m_PyMethodCache.end(), nullptr);
}

EntityTreeModelWrapper::EntityTreeModelWrapper(::Akonadi::Monitor * monitor, ::QObject * parent) : Akonadi::EntityTreeModel(monitor, parent)
{
}

::QModelIndex EntityTreeModelWrapper::buddy(const ::QModelIndex & index) const
{
    static const char *funcName = "buddy";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_Akonadi_EntityTreeModel_TypeF(), gil, funcName, m_PyMethodCache[0], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractItemModel::buddy(index);
    }
    return TrashFilterProxyModelWrapper::sbk_o_buddy("EntityTreeModel", funcName, gil, pyOverride, index);
}

bool EntityTreeModelWrapper::canDropMimeData(const ::QMimeData * data, ::Qt::DropAction action, int row, int column, const ::QModelIndex & parent) const
{
    static const char *funcName = "canDropMimeData";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_Akonadi_EntityTreeModel_TypeF(), gil, funcName, m_PyMethodCache[1], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractItemModel::canDropMimeData(data, action, row, column, parent);
    }
    return TrashFilterProxyModelWrapper::sbk_o_canDropMimeData("EntityTreeModel", funcName, gil, pyOverride, data, action, row, column, parent);
}

bool EntityTreeModelWrapper::canFetchMore(const ::QModelIndex & parent) const
{
    static const char *funcName = "canFetchMore";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_Akonadi_EntityTreeModel_TypeF(), gil, funcName, m_PyMethodCache[2], nameCache));
    if (pyOverride.isNull()) {
        return this->::Akonadi::EntityTreeModel::canFetchMore(parent);
    }
    return TrashFilterProxyModelWrapper::sbk_o_canFetchMore("EntityTreeModel", funcName, gil, pyOverride, parent);
}

void EntityTreeModelWrapper::childEvent(::QChildEvent * event)
{
    static const char *funcName = "childEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_Akonadi_EntityTreeModel_TypeF(), gil, funcName, m_PyMethodCache[3], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::childEvent(event);
    }
    TrashFilterProxyModelWrapper::sbk_o_childEvent("EntityTreeModel", funcName, gil, pyOverride, event);
}

bool EntityTreeModelWrapper::clearItemData(const ::QModelIndex & index)
{
    static const char *funcName = "clearItemData";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_Akonadi_EntityTreeModel_TypeF(), gil, funcName, m_PyMethodCache[4], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractItemModel::clearItemData(index);
    }
    return TrashFilterProxyModelWrapper::sbk_o_canFetchMore("EntityTreeModel", funcName, gil, pyOverride, index);
}

int EntityTreeModelWrapper::columnCount(const ::QModelIndex & parent) const
{
    static const char *funcName = "columnCount";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_Akonadi_EntityTreeModel_TypeF(), gil, funcName, m_PyMethodCache[5], nameCache));
    if (pyOverride.isNull()) {
        return this->::Akonadi::EntityTreeModel::columnCount(parent);
    }
    return TrashFilterProxyModelWrapper::sbk_o_columnCount("EntityTreeModel", funcName, gil, pyOverride, parent);
}

void EntityTreeModelWrapper::connectNotify(const ::QMetaMethod & signal)
{
    static const char *funcName = "connectNotify";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_Akonadi_EntityTreeModel_TypeF(), gil, funcName, m_PyMethodCache[6], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::connectNotify(signal);
    }
    TrashFilterProxyModelWrapper::sbk_o_connectNotify("EntityTreeModel", funcName, gil, pyOverride, signal);
}

void EntityTreeModelWrapper::customEvent(::QEvent * event)
{
    static const char *funcName = "customEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_Akonadi_EntityTreeModel_TypeF(), gil, funcName, m_PyMethodCache[7], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::customEvent(event);
    }
    TrashFilterProxyModelWrapper::sbk_o_customEvent("EntityTreeModel", funcName, gil, pyOverride, event);
}

::QVariant EntityTreeModelWrapper::data(const ::QModelIndex & index, int role) const
{
    static const char *funcName = "data";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_Akonadi_EntityTreeModel_TypeF(), gil, funcName, m_PyMethodCache[8], nameCache));
    if (pyOverride.isNull()) {
        return this->::Akonadi::EntityTreeModel::data(index, role);
    }
    return TrashFilterProxyModelWrapper::sbk_o_data("EntityTreeModel", funcName, gil, pyOverride, index, role);
}

void EntityTreeModelWrapper::disconnectNotify(const ::QMetaMethod & signal)
{
    static const char *funcName = "disconnectNotify";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_Akonadi_EntityTreeModel_TypeF(), gil, funcName, m_PyMethodCache[9], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::disconnectNotify(signal);
    }
    TrashFilterProxyModelWrapper::sbk_o_connectNotify("EntityTreeModel", funcName, gil, pyOverride, signal);
}

bool EntityTreeModelWrapper::dropMimeData(const ::QMimeData * data, ::Qt::DropAction action, int row, int column, const ::QModelIndex & parent)
{
    static const char *funcName = "dropMimeData";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_Akonadi_EntityTreeModel_TypeF(), gil, funcName, m_PyMethodCache[10], nameCache));
    if (pyOverride.isNull()) {
        return this->::Akonadi::EntityTreeModel::dropMimeData(data, action, row, column, parent);
    }
    return TrashFilterProxyModelWrapper::sbk_o_canDropMimeData("EntityTreeModel", funcName, gil, pyOverride, data, action, row, column, parent);
}

int EntityTreeModelWrapper::entityColumnCount(::Akonadi::EntityTreeModel::HeaderGroup headerGroup) const
{
    static const char *funcName = "entityColumnCount";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_Akonadi_EntityTreeModel_TypeF(), gil, funcName, m_PyMethodCache[11], nameCache));
    if (pyOverride.isNull()) {
        return this->::Akonadi::EntityTreeModel::entityColumnCount(headerGroup);
    }
    return sbk_o_entityColumnCount("EntityTreeModel", funcName, gil, pyOverride, headerGroup);
}

int EntityTreeModelWrapper::sbk_o_entityColumnCount([[maybe_unused]] const char *ownerClassName, [[maybe_unused]] const char *funcName, [[maybe_unused]] Shiboken::GilState &gil, [[maybe_unused]] const Shiboken::AutoDecRef &pyOverride, [[maybe_unused]] ::Akonadi::EntityTreeModel::HeaderGroup headerGroup)
{
#if !defined(PYPY_VERSION) && (!defined(Py_LIMITED_API) || Py_LIMITED_API >= 0x030C0000)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Enum::getConverter(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_EntityTreeModel_HeaderGroup_IDX]))), &headerGroup)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Enum::getConverter(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_EntityTreeModel_HeaderGroup_IDX]))), &headerGroup)
    ));
#endif

#if !defined(PYPY_VERSION) && (!defined(Py_LIMITED_API) || Py_LIMITED_API >= 0x030C0000)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint(ownerClassName, funcName);
        return 0;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue(ownerClassName, funcName, "int", Py_TYPE(pyResult)->tp_name);
        return 0;
    }
    int cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

::QVariant EntityTreeModelWrapper::entityData(const ::Akonadi::Collection & collection, int column, int role) const
{
    static const char *funcName = "entityData";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_Akonadi_EntityTreeModel_TypeF(), gil, funcName, m_PyMethodCache[12], nameCache));
    if (pyOverride.isNull()) {
        return this->::Akonadi::EntityTreeModel::entityData(collection, column, role);
    }
    return sbk_o_entityData("EntityTreeModel", funcName, gil, pyOverride, collection, column, role);
}

::QVariant EntityTreeModelWrapper::sbk_o_entityData([[maybe_unused]] const char *ownerClassName, [[maybe_unused]] const char *funcName, [[maybe_unused]] Shiboken::GilState &gil, [[maybe_unused]] const Shiboken::AutoDecRef &pyOverride, [[maybe_unused]] const ::Akonadi::Collection & collection, [[maybe_unused]] int column, [[maybe_unused]] int role)
{
#if !defined(PYPY_VERSION) && (!defined(Py_LIMITED_API) || Py_LIMITED_API >= 0x030C0000)
    PyObject *pyArgArray[3] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Collection_IDX]), &collection),
        Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &column),
        Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &role)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(Nii)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Collection_IDX]), &collection),
        column,
        role
    ));
#endif

#if !defined(PYPY_VERSION) && (!defined(Py_LIMITED_API) || Py_LIMITED_API >= 0x030C0000)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 3, nullptr));
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
    Py_DECREF(pyArgArray[2]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint(ownerClassName, funcName);
        return ::QVariant();
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue(ownerClassName, funcName, "QVariant", Py_TYPE(pyResult)->tp_name);
        return ::QVariant();
    }
    ::QVariant cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

::QVariant EntityTreeModelWrapper::entityData(const ::Akonadi::Item & item, int column, int role) const
{
    static const char *funcName = "entityData";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_Akonadi_EntityTreeModel_TypeF(), gil, funcName, m_PyMethodCache[13], nameCache));
    if (pyOverride.isNull()) {
        return this->::Akonadi::EntityTreeModel::entityData(item, column, role);
    }
    return sbk_o_entityData("EntityTreeModel", funcName, gil, pyOverride, item, column, role);
}

::QVariant EntityTreeModelWrapper::sbk_o_entityData([[maybe_unused]] const char *ownerClassName, [[maybe_unused]] const char *funcName, [[maybe_unused]] Shiboken::GilState &gil, [[maybe_unused]] const Shiboken::AutoDecRef &pyOverride, [[maybe_unused]] const ::Akonadi::Item & item, [[maybe_unused]] int column, [[maybe_unused]] int role)
{
#if !defined(PYPY_VERSION) && (!defined(Py_LIMITED_API) || Py_LIMITED_API >= 0x030C0000)
    PyObject *pyArgArray[3] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Item_IDX]), &item),
        Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &column),
        Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &role)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(Nii)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Item_IDX]), &item),
        column,
        role
    ));
#endif

#if !defined(PYPY_VERSION) && (!defined(Py_LIMITED_API) || Py_LIMITED_API >= 0x030C0000)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 3, nullptr));
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
    Py_DECREF(pyArgArray[2]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint(ownerClassName, funcName);
        return ::QVariant();
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue(ownerClassName, funcName, "QVariant", Py_TYPE(pyResult)->tp_name);
        return ::QVariant();
    }
    ::QVariant cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

::QVariant EntityTreeModelWrapper::entityHeaderData(int section, ::Qt::Orientation orientation, int role, ::Akonadi::EntityTreeModel::HeaderGroup headerGroup) const
{
    static const char *funcName = "entityHeaderData";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_Akonadi_EntityTreeModel_TypeF(), gil, funcName, m_PyMethodCache[14], nameCache));
    if (pyOverride.isNull()) {
        return this->::Akonadi::EntityTreeModel::entityHeaderData(section, orientation, role, headerGroup);
    }
    return sbk_o_entityHeaderData("EntityTreeModel", funcName, gil, pyOverride, section, orientation, role, headerGroup);
}

::QVariant EntityTreeModelWrapper::sbk_o_entityHeaderData([[maybe_unused]] const char *ownerClassName, [[maybe_unused]] const char *funcName, [[maybe_unused]] Shiboken::GilState &gil, [[maybe_unused]] const Shiboken::AutoDecRef &pyOverride, [[maybe_unused]] int section, [[maybe_unused]] ::Qt::Orientation orientation, [[maybe_unused]] int role, [[maybe_unused]] ::Akonadi::EntityTreeModel::HeaderGroup headerGroup)
{
#if !defined(PYPY_VERSION) && (!defined(Py_LIMITED_API) || Py_LIMITED_API >= 0x030C0000)
    PyObject *pyArgArray[4] = {
        Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &section),
        Shiboken::Conversions::copyToPython(Shiboken::Enum::getConverter(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_Orientation_IDX]))), &orientation),
        Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &role),
        Shiboken::Conversions::copyToPython(Shiboken::Enum::getConverter(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_EntityTreeModel_HeaderGroup_IDX]))), &headerGroup)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(iNiN)",
        section,
        Shiboken::Conversions::copyToPython(Shiboken::Enum::getConverter(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_Orientation_IDX]))), &orientation),
        role,
        Shiboken::Conversions::copyToPython(Shiboken::Enum::getConverter(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_EntityTreeModel_HeaderGroup_IDX]))), &headerGroup)
    ));
#endif

#if !defined(PYPY_VERSION) && (!defined(Py_LIMITED_API) || Py_LIMITED_API >= 0x030C0000)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 4, nullptr));
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
    Py_DECREF(pyArgArray[2]);
    Py_DECREF(pyArgArray[3]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint(ownerClassName, funcName);
        return ::QVariant();
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue(ownerClassName, funcName, "QVariant", Py_TYPE(pyResult)->tp_name);
        return ::QVariant();
    }
    ::QVariant cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

bool EntityTreeModelWrapper::event(::QEvent * event)
{
    static const char *funcName = "event";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_Akonadi_EntityTreeModel_TypeF(), gil, funcName, m_PyMethodCache[15], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::event(event);
    }
    return TrashFilterProxyModelWrapper::sbk_o_event("EntityTreeModel", funcName, gil, pyOverride, event);
}

bool EntityTreeModelWrapper::eventFilter(::QObject * watched, ::QEvent * event)
{
    static const char *funcName = "eventFilter";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_Akonadi_EntityTreeModel_TypeF(), gil, funcName, m_PyMethodCache[16], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::eventFilter(watched, event);
    }
    return TrashFilterProxyModelWrapper::sbk_o_eventFilter("EntityTreeModel", funcName, gil, pyOverride, watched, event);
}

void EntityTreeModelWrapper::fetchMore(const ::QModelIndex & parent)
{
    static const char *funcName = "fetchMore";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_Akonadi_EntityTreeModel_TypeF(), gil, funcName, m_PyMethodCache[17], nameCache));
    if (pyOverride.isNull()) {
        return this->::Akonadi::EntityTreeModel::fetchMore(parent);
    }
    TrashFilterProxyModelWrapper::sbk_o_fetchMore("EntityTreeModel", funcName, gil, pyOverride, parent);
}

::QFlags<Qt::ItemFlag> EntityTreeModelWrapper::flags(const ::QModelIndex & index) const
{
    static const char *funcName = "flags";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_Akonadi_EntityTreeModel_TypeF(), gil, funcName, m_PyMethodCache[18], nameCache));
    if (pyOverride.isNull()) {
        return this->::Akonadi::EntityTreeModel::flags(index);
    }
    return TrashFilterProxyModelWrapper::sbk_o_flags("EntityTreeModel", funcName, gil, pyOverride, index);
}

bool EntityTreeModelWrapper::hasChildren(const ::QModelIndex & parent) const
{
    static const char *funcName = "hasChildren";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_Akonadi_EntityTreeModel_TypeF(), gil, funcName, m_PyMethodCache[19], nameCache));
    if (pyOverride.isNull()) {
        return this->::Akonadi::EntityTreeModel::hasChildren(parent);
    }
    return TrashFilterProxyModelWrapper::sbk_o_canFetchMore("EntityTreeModel", funcName, gil, pyOverride, parent);
}

::QVariant EntityTreeModelWrapper::headerData(int section, ::Qt::Orientation orientation, int role) const
{
    static const char *funcName = "headerData";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_Akonadi_EntityTreeModel_TypeF(), gil, funcName, m_PyMethodCache[20], nameCache));
    if (pyOverride.isNull()) {
        return this->::Akonadi::EntityTreeModel::headerData(section, orientation, role);
    }
    return TrashFilterProxyModelWrapper::sbk_o_headerData("EntityTreeModel", funcName, gil, pyOverride, section, orientation, role);
}

::QModelIndex EntityTreeModelWrapper::index(int row, int column, const ::QModelIndex & parent) const
{
    static const char *funcName = "index";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_Akonadi_EntityTreeModel_TypeF(), gil, funcName, m_PyMethodCache[21], nameCache));
    if (pyOverride.isNull()) {
        return this->::Akonadi::EntityTreeModel::index(row, column, parent);
    }
    return TrashFilterProxyModelWrapper::sbk_o_index("EntityTreeModel", funcName, gil, pyOverride, row, column, parent);
}

::QMap<int,QVariant> EntityTreeModelWrapper::itemData(const ::QModelIndex & index) const
{
    static const char *funcName = "itemData";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_Akonadi_EntityTreeModel_TypeF(), gil, funcName, m_PyMethodCache[22], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractItemModel::itemData(index);
    }
    return TrashFilterProxyModelWrapper::sbk_o_itemData("EntityTreeModel", funcName, gil, pyOverride, index);
}

::QList<QModelIndex> EntityTreeModelWrapper::match(const ::QModelIndex & start, int role, const ::QVariant & value, int hits, ::QFlags<Qt::MatchFlag> flags) const
{
    static const char *funcName = "match";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_Akonadi_EntityTreeModel_TypeF(), gil, funcName, m_PyMethodCache[23], nameCache));
    if (pyOverride.isNull()) {
        return this->::Akonadi::EntityTreeModel::match(start, role, value, hits, flags);
    }
    return TrashFilterProxyModelWrapper::sbk_o_match("EntityTreeModel", funcName, gil, pyOverride, start, role, value, hits, flags);
}

::QMimeData * EntityTreeModelWrapper::mimeData(const ::QList<QModelIndex> & indexes) const
{
    static const char *funcName = "mimeData";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_Akonadi_EntityTreeModel_TypeF(), gil, funcName, m_PyMethodCache[24], nameCache));
    if (pyOverride.isNull()) {
        return this->::Akonadi::EntityTreeModel::mimeData(indexes);
    }
    return TrashFilterProxyModelWrapper::sbk_o_mimeData("EntityTreeModel", funcName, gil, pyOverride, indexes);
}

::QStringList EntityTreeModelWrapper::mimeTypes() const
{
    static const char *funcName = "mimeTypes";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_Akonadi_EntityTreeModel_TypeF(), gil, funcName, m_PyMethodCache[25], nameCache));
    if (pyOverride.isNull()) {
        return this->::Akonadi::EntityTreeModel::mimeTypes();
    }
    return TrashFilterProxyModelWrapper::sbk_o_mimeTypes("EntityTreeModel", funcName, gil, pyOverride);
}

bool EntityTreeModelWrapper::moveColumns(const ::QModelIndex & sourceParent, int sourceColumn, int count, const ::QModelIndex & destinationParent, int destinationChild)
{
    static const char *funcName = "moveColumns";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_Akonadi_EntityTreeModel_TypeF(), gil, funcName, m_PyMethodCache[26], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractItemModel::moveColumns(sourceParent, sourceColumn, count, destinationParent, destinationChild);
    }
    return TrashFilterProxyModelWrapper::sbk_o_moveColumns("EntityTreeModel", funcName, gil, pyOverride, sourceParent, sourceColumn, count, destinationParent, destinationChild);
}

bool EntityTreeModelWrapper::moveRows(const ::QModelIndex & sourceParent, int sourceRow, int count, const ::QModelIndex & destinationParent, int destinationChild)
{
    static const char *funcName = "moveRows";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_Akonadi_EntityTreeModel_TypeF(), gil, funcName, m_PyMethodCache[27], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractItemModel::moveRows(sourceParent, sourceRow, count, destinationParent, destinationChild);
    }
    return TrashFilterProxyModelWrapper::sbk_o_moveColumns("EntityTreeModel", funcName, gil, pyOverride, sourceParent, sourceRow, count, destinationParent, destinationChild);
}

void EntityTreeModelWrapper::multiData(const ::QModelIndex & index, ::QModelRoleDataSpan roleDataSpan) const
{
    static const char *funcName = "multiData";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_Akonadi_EntityTreeModel_TypeF(), gil, funcName, m_PyMethodCache[28], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractItemModel::multiData(index, roleDataSpan);
    }
    TrashFilterProxyModelWrapper::sbk_o_multiData("EntityTreeModel", funcName, gil, pyOverride, index, roleDataSpan);
}

::QModelIndex EntityTreeModelWrapper::parent(const ::QModelIndex & index) const
{
    static const char *funcName = "parent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_Akonadi_EntityTreeModel_TypeF(), gil, funcName, m_PyMethodCache[29], nameCache));
    if (pyOverride.isNull()) {
        return this->::Akonadi::EntityTreeModel::parent(index);
    }
    return TrashFilterProxyModelWrapper::sbk_o_buddy("EntityTreeModel", funcName, gil, pyOverride, index);
}

void EntityTreeModelWrapper::resetInternalData()
{
    static const char *funcName = "resetInternalData";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_Akonadi_EntityTreeModel_TypeF(), gil, funcName, m_PyMethodCache[30], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractItemModel::resetInternalData();
    }
    TrashFilterProxyModelWrapper::sbk_o_resetInternalData("EntityTreeModel", funcName, gil, pyOverride);
}

void EntityTreeModelWrapper::revert()
{
    static const char *funcName = "revert";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_Akonadi_EntityTreeModel_TypeF(), gil, funcName, m_PyMethodCache[31], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractItemModel::revert();
    }
    TrashFilterProxyModelWrapper::sbk_o_resetInternalData("EntityTreeModel", funcName, gil, pyOverride);
}

::QHash<int,QByteArray> EntityTreeModelWrapper::roleNames() const
{
    static const char *funcName = "roleNames";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_Akonadi_EntityTreeModel_TypeF(), gil, funcName, m_PyMethodCache[32], nameCache));
    if (pyOverride.isNull()) {
        return this->::Akonadi::EntityTreeModel::roleNames();
    }
    return TrashFilterProxyModelWrapper::sbk_o_roleNames("EntityTreeModel", funcName, gil, pyOverride);
}

int EntityTreeModelWrapper::rowCount(const ::QModelIndex & parent) const
{
    static const char *funcName = "rowCount";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_Akonadi_EntityTreeModel_TypeF(), gil, funcName, m_PyMethodCache[33], nameCache));
    if (pyOverride.isNull()) {
        return this->::Akonadi::EntityTreeModel::rowCount(parent);
    }
    return TrashFilterProxyModelWrapper::sbk_o_columnCount("EntityTreeModel", funcName, gil, pyOverride, parent);
}

bool EntityTreeModelWrapper::setData(const ::QModelIndex & index, const ::QVariant & value, int role)
{
    static const char *funcName = "setData";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_Akonadi_EntityTreeModel_TypeF(), gil, funcName, m_PyMethodCache[34], nameCache));
    if (pyOverride.isNull()) {
        return this->::Akonadi::EntityTreeModel::setData(index, value, role);
    }
    return TrashFilterProxyModelWrapper::sbk_o_setData("EntityTreeModel", funcName, gil, pyOverride, index, value, role);
}

bool EntityTreeModelWrapper::setHeaderData(int section, ::Qt::Orientation orientation, const ::QVariant & value, int role)
{
    static const char *funcName = "setHeaderData";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_Akonadi_EntityTreeModel_TypeF(), gil, funcName, m_PyMethodCache[35], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractItemModel::setHeaderData(section, orientation, value, role);
    }
    return TrashFilterProxyModelWrapper::sbk_o_setHeaderData("EntityTreeModel", funcName, gil, pyOverride, section, orientation, value, role);
}

bool EntityTreeModelWrapper::setItemData(const ::QModelIndex & index, const ::QMap<int,QVariant> & roles)
{
    static const char *funcName = "setItemData";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_Akonadi_EntityTreeModel_TypeF(), gil, funcName, m_PyMethodCache[36], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractItemModel::setItemData(index, roles);
    }
    return TrashFilterProxyModelWrapper::sbk_o_setItemData("EntityTreeModel", funcName, gil, pyOverride, index, roles);
}

::QModelIndex EntityTreeModelWrapper::sibling(int row, int column, const ::QModelIndex & idx) const
{
    static const char *funcName = "sibling";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_Akonadi_EntityTreeModel_TypeF(), gil, funcName, m_PyMethodCache[37], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractItemModel::sibling(row, column, idx);
    }
    return TrashFilterProxyModelWrapper::sbk_o_index("EntityTreeModel", funcName, gil, pyOverride, row, column, idx);
}

void EntityTreeModelWrapper::sort(int column, ::Qt::SortOrder order)
{
    static const char *funcName = "sort";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_Akonadi_EntityTreeModel_TypeF(), gil, funcName, m_PyMethodCache[38], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractItemModel::sort(column, order);
    }
    TrashFilterProxyModelWrapper::sbk_o_sort("EntityTreeModel", funcName, gil, pyOverride, column, order);
}

::QSize EntityTreeModelWrapper::span(const ::QModelIndex & index) const
{
    static const char *funcName = "span";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_Akonadi_EntityTreeModel_TypeF(), gil, funcName, m_PyMethodCache[39], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractItemModel::span(index);
    }
    return TrashFilterProxyModelWrapper::sbk_o_span("EntityTreeModel", funcName, gil, pyOverride, index);
}

bool EntityTreeModelWrapper::submit()
{
    static const char *funcName = "submit";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_Akonadi_EntityTreeModel_TypeF(), gil, funcName, m_PyMethodCache[40], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractItemModel::submit();
    }
    return TrashFilterProxyModelWrapper::sbk_o_submit("EntityTreeModel", funcName, gil, pyOverride);
}

::QFlags<Qt::DropAction> EntityTreeModelWrapper::supportedDragActions() const
{
    static const char *funcName = "supportedDragActions";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_Akonadi_EntityTreeModel_TypeF(), gil, funcName, m_PyMethodCache[41], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractItemModel::supportedDragActions();
    }
    return TrashFilterProxyModelWrapper::sbk_o_supportedDragActions("EntityTreeModel", funcName, gil, pyOverride);
}

::QFlags<Qt::DropAction> EntityTreeModelWrapper::supportedDropActions() const
{
    static const char *funcName = "supportedDropActions";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_Akonadi_EntityTreeModel_TypeF(), gil, funcName, m_PyMethodCache[42], nameCache));
    if (pyOverride.isNull()) {
        return this->::Akonadi::EntityTreeModel::supportedDropActions();
    }
    return TrashFilterProxyModelWrapper::sbk_o_supportedDragActions("EntityTreeModel", funcName, gil, pyOverride);
}

void EntityTreeModelWrapper::timerEvent(::QTimerEvent * event)
{
    static const char *funcName = "timerEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_Akonadi_EntityTreeModel_TypeF(), gil, funcName, m_PyMethodCache[43], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::timerEvent(event);
    }
    TrashFilterProxyModelWrapper::sbk_o_timerEvent("EntityTreeModel", funcName, gil, pyOverride, event);
}

const QMetaObject *EntityTreeModelWrapper::metaObject() const
{
    if (QObject::d_ptr->metaObject != nullptr)
        return QObject::d_ptr->dynamicMetaObject();
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf == nullptr)
        return Akonadi::EntityTreeModel::metaObject();
    return PySide::SignalManager::retrieveMetaObject(reinterpret_cast<PyObject *>(pySelf));
}

int EntityTreeModelWrapper::qt_metacall(QMetaObject::Call call, int id, void **args)
{
    int result = Akonadi::EntityTreeModel::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

void *EntityTreeModelWrapper::qt_metacast(const char *_clname)
{
    if (_clname == nullptr)
        return {};
    if (SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this)) {
        auto *obSelf = reinterpret_cast<PyObject *>(pySelf);
        if (PySide::inherits(Py_TYPE(obSelf), _clname))
            return static_cast<void *>(const_cast< EntityTreeModelWrapper *>(this));
    }
    return Akonadi::EntityTreeModel::qt_metacast(_clname);
}

EntityTreeModelWrapper::~EntityTreeModelWrapper()
{
    auto *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this, Sbk_Akonadi_EntityTreeModel_TypeF());
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_Akonadi_EntityTreeModel_Init(PyObject *self, PyObject *args, [[maybe_unused]] PyObject *kwds)
{
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::Akonadi::EntityTreeModel >()))
        return -1;

    EntityTreeModelWrapper *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_ParseTuple(args, "|OO:EntityTreeModel", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: EntityTreeModel::EntityTreeModel(Akonadi::Monitor*,QObject*=)
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Monitor_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // EntityTreeModel(Akonadi::Monitor*,QObject*)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[1])))) {
            overloadId = 0; // EntityTreeModel::EntityTreeModel(Akonadi::Monitor*,QObject*=)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", SbkAkonadiCoreTypeStructs[SBK_Akonadi_EntityTreeModel_IDX]);

    // Resolve keyword arguments
    {
        if (kwds != nullptr && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"parent", 1}};
            if (!Shiboken::parseConstructorKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                || (pyArgs[1] != nullptr && !((pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[1])))))) {
                Py_XINCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkAkonadiCoreTypeStructs[SBK_Akonadi_EntityTreeModel_IDX]);
            }
        }
    }

    // PyMI support
    [[maybe_unused]] const bool usesPyMI = Shiboken::callInheritedInit(self, args, errInfo.isNull() ? kwds : errInfo.object(), SbkAkonadiCoreTypeStructs[SBK_Akonadi_EntityTreeModel_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return -1;
        ::Akonadi::Monitor *cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        if (!Shiboken::Object::isValid(pyArgs[1]))
            return -1;
        ::QObject *cppArg1 = nullptr;
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // EntityTreeModel::EntityTreeModel(Akonadi::Monitor*,QObject*=)
            void *addr = PySide::nextQObjectMemoryAddr();
            if (addr != nullptr) {
                cptr = new (addr) EntityTreeModelWrapper(cppArg0, cppArg1);
                PySide::setNextQObjectMemoryAddr(nullptr);
            } else {
                cptr = new EntityTreeModelWrapper(cppArg0, cppArg1);
            }

        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< Akonadi::EntityTreeModel >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", SbkAkonadiCoreTypeStructs[SBK_Akonadi_EntityTreeModel_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);

    // QObject setup
    PySide::Signal::updateSourceObject(self);
    const auto *metaObject = cptr->metaObject(); // <- init python qt properties
    if (!errInfo.isNull() && PyDict_Check(errInfo.object())) {
        if (!PySide::fillQtProperties(self, metaObject, errInfo, usesPyMI))
            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkAkonadiCoreTypeStructs[SBK_Akonadi_EntityTreeModel_IDX]);
    };


    return 1;
}

static PyObject *Sbk_Akonadi_EntityTreeModelFunc_canFetchMore(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::EntityTreeModel *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_EntityTreeModel_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: QAbstractItemModel::canFetchMore(const QModelIndex&)const->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelIndex_IDX]), (pyArg)))) {
        overloadId = 0; // QAbstractItemModel::canFetchMore(const QModelIndex&)const->bool
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "canFetchMore", SbkAkonadiCoreTypeStructs[SBK_Akonadi_EntityTreeModel_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QModelIndex cppArg0_local;
        ::QModelIndex *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // QAbstractItemModel::canFetchMore(const QModelIndex&)const->bool
            bool cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? const_cast<const ::Akonadi::EntityTreeModel *>(cppSelf)->::Akonadi::EntityTreeModel::canFetchMore(*cppArg0)
                : const_cast<const ::Akonadi::EntityTreeModel *>(cppSelf)->canFetchMore(*cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_EntityTreeModelFunc_clearAndReset(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::EntityTreeModel *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_EntityTreeModel_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // EntityTreeModel::clearAndReset()
        cppSelf->clearAndReset();
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_Akonadi_EntityTreeModelFunc_collectionFetchStrategy(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::EntityTreeModel *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_EntityTreeModel_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // EntityTreeModel::collectionFetchStrategy()const->Akonadi::EntityTreeModel::CollectionFetchStrategy
        Akonadi::EntityTreeModel::CollectionFetchStrategy cppResult = const_cast<const ::Akonadi::EntityTreeModel *>(cppSelf)->collectionFetchStrategy();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Enum::getConverter(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_EntityTreeModel_CollectionFetchStrategy_IDX]))), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_EntityTreeModelFunc_columnCount(PyObject *self, PyObject *args, [[maybe_unused]] PyObject *kwds)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::EntityTreeModel *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_EntityTreeModel_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 1));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "columnCount", errInfo, SbkAkonadiCoreTypeStructs[SBK_Akonadi_EntityTreeModel_IDX]);

    if (PyArg_ParseTuple(args, "|O:columnCount", &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QAbstractItemModel::columnCount(const QModelIndex&=)const->int
    if (numArgs == 0) {
        overloadId = 0; // columnCount(QModelIndex)const
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelIndex_IDX]), (pyArgs[0])))) {
        overloadId = 0; // QAbstractItemModel::columnCount(const QModelIndex&=)const->int
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "columnCount", SbkAkonadiCoreTypeStructs[SBK_Akonadi_EntityTreeModel_IDX]);

    // Call function/method
    {
        if (kwds != nullptr && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"parent", 0}};
            if (!Shiboken::parseKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                || (pyArgs[0] != nullptr && !((pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelIndex_IDX]), (pyArgs[0])))))) {
                Py_XINCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "columnCount", errInfo, SbkAkonadiCoreTypeStructs[SBK_Akonadi_EntityTreeModel_IDX]);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QModelIndex cppArg0_local = QModelIndex();
        ::QModelIndex *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0]) {
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);
            }

        if (Shiboken::Errors::occurred() == nullptr) {
            // QAbstractItemModel::columnCount(const QModelIndex&=)const->int
            int cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? const_cast<const ::Akonadi::EntityTreeModel *>(cppSelf)->::Akonadi::EntityTreeModel::columnCount(*cppArg0)
                : const_cast<const ::Akonadi::EntityTreeModel *>(cppSelf)->columnCount(*cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_EntityTreeModelFunc_data(PyObject *self, PyObject *args, [[maybe_unused]] PyObject *kwds)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::EntityTreeModel *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_EntityTreeModel_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "data", errInfo, SbkAkonadiCoreTypeStructs[SBK_Akonadi_EntityTreeModel_IDX]);

    if (PyArg_ParseTuple(args, "|OO:data", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QAbstractItemModel::data(const QModelIndex&,int=)const->QVariant
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelIndex_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // data(QModelIndex,int)const
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))) {
            overloadId = 0; // QAbstractItemModel::data(const QModelIndex&,int=)const->QVariant
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "data", SbkAkonadiCoreTypeStructs[SBK_Akonadi_EntityTreeModel_IDX]);

    // Call function/method
    {
        if (kwds != nullptr && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"role", 1}};
            if (!Shiboken::parseKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                || (pyArgs[1] != nullptr && !((pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))))) {
                Py_XINCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "data", errInfo, SbkAkonadiCoreTypeStructs[SBK_Akonadi_EntityTreeModel_IDX]);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QModelIndex cppArg0_local;
        ::QModelIndex *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0].isValue())
            pythonToCpp[0](pyArgs[0], &cppArg0_local);
        else
            pythonToCpp[0](pyArgs[0], &cppArg0);

        int cppArg1 = Qt::DisplayRole;
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // QAbstractItemModel::data(const QModelIndex&,int=)const->QVariant
            QVariant cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? const_cast<const ::Akonadi::EntityTreeModel *>(cppSelf)->::Akonadi::EntityTreeModel::data(*cppArg0, cppArg1)
                : const_cast<const ::Akonadi::EntityTreeModel *>(cppSelf)->data(*cppArg0, cppArg1);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_EntityTreeModelFunc_dropMimeData(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::EntityTreeModel *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_EntityTreeModel_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp[5];
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "dropMimeData", 5, 5, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3]), &(pyArgs[4])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QAbstractItemModel::dropMimeData(const QMimeData*,Qt::DropAction,int,int,const QModelIndex&)->bool
    if (numArgs == 5
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMimeData_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Enum::getConverter(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_DropAction_IDX]))), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2])))
        && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[3])))
        && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelIndex_IDX]), (pyArgs[4])))) {
        overloadId = 0; // QAbstractItemModel::dropMimeData(const QMimeData*,Qt::DropAction,int,int,const QModelIndex&)->bool
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "dropMimeData", SbkAkonadiCoreTypeStructs[SBK_Akonadi_EntityTreeModel_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QMimeData *cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::Qt::DropAction cppArg1{Qt::IgnoreAction};
        pythonToCpp[1](pyArgs[1], &cppArg1);
        int cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);
        int cppArg3;
        pythonToCpp[3](pyArgs[3], &cppArg3);
        if (!Shiboken::Object::isValid(pyArgs[4]))
            return {};
        ::QModelIndex cppArg4_local;
        ::QModelIndex *cppArg4 = &cppArg4_local;
        if (pythonToCpp[4].isValue())
            pythonToCpp[4](pyArgs[4], &cppArg4_local);
        else
            pythonToCpp[4](pyArgs[4], &cppArg4);


        if (Shiboken::Errors::occurred() == nullptr) {
            // QAbstractItemModel::dropMimeData(const QMimeData*,Qt::DropAction,int,int,const QModelIndex&)->bool
            bool cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::Akonadi::EntityTreeModel::dropMimeData(cppArg0, cppArg1, cppArg2, cppArg3, *cppArg4)
                : cppSelf->dropMimeData(cppArg0, cppArg1, cppArg2, cppArg3, *cppArg4);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_EntityTreeModelFunc_entityColumnCount(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::EntityTreeModel *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_EntityTreeModel_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: EntityTreeModel::entityColumnCount(Akonadi::EntityTreeModel::HeaderGroup)const->int
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Enum::getConverter(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_EntityTreeModel_HeaderGroup_IDX]))), (pyArg)))) {
        overloadId = 0; // EntityTreeModel::entityColumnCount(Akonadi::EntityTreeModel::HeaderGroup)const->int
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "entityColumnCount", SbkAkonadiCoreTypeStructs[SBK_Akonadi_EntityTreeModel_IDX]);

    // Call function/method
    {
        ::Akonadi::EntityTreeModel::HeaderGroup cppArg0{Akonadi::EntityTreeModel::EntityTreeHeaders};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // EntityTreeModel::entityColumnCount(Akonadi::EntityTreeModel::HeaderGroup)const->int
            int cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? const_cast<const ::Akonadi::EntityTreeModel *>(cppSelf)->::Akonadi::EntityTreeModel::entityColumnCount(cppArg0)
                : const_cast<const ::Akonadi::EntityTreeModel *>(cppSelf)->entityColumnCount(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_EntityTreeModelFunc_entityData(PyObject *self, PyObject *args, [[maybe_unused]] PyObject *kwds)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::EntityTreeModel *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_EntityTreeModel_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 2, 3));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "entityData", errInfo, SbkAkonadiCoreTypeStructs[SBK_Akonadi_EntityTreeModel_IDX]);

    if (PyArg_ParseTuple(args, "|OOO:entityData", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: EntityTreeModel::entityData(const Akonadi::Item&,int,int=)const->QVariant
    // 1: EntityTreeModel::entityData(const Akonadi::Collection&,int,int=)const->QVariant
    if (numArgs >= 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Collection_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))) {
        if (numArgs == 2) {
            overloadId = 1; // entityData(Akonadi::Collection,int,int)const
        } else if (numArgs >= 3
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2])))) {
            overloadId = 1; // EntityTreeModel::entityData(const Akonadi::Collection&,int,int=)const->QVariant
        }
    } else if (numArgs >= 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Item_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))) {
        if (numArgs == 2) {
            overloadId = 0; // entityData(Akonadi::Item,int,int)const
        } else if (numArgs >= 3
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2])))) {
            overloadId = 0; // EntityTreeModel::entityData(const Akonadi::Item&,int,int=)const->QVariant
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "entityData", SbkAkonadiCoreTypeStructs[SBK_Akonadi_EntityTreeModel_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // entityData(const Akonadi::Item &item, int column, int role) const
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"role", 2}};
                if (!Shiboken::parseKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                    || (pyArgs[2] != nullptr && !((pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2])))))) {
                    Py_XINCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "entityData", errInfo, SbkAkonadiCoreTypeStructs[SBK_Akonadi_EntityTreeModel_IDX]);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::Akonadi::Item cppArg0_local;
            ::Akonadi::Item *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            int cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            int cppArg2 = Qt::DisplayRole;
            if (pythonToCpp[2])
                pythonToCpp[2](pyArgs[2], &cppArg2);

            if (Shiboken::Errors::occurred() == nullptr) {
                // EntityTreeModel::entityData(const Akonadi::Item&,int,int=)const->QVariant
                QVariant cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                    ? const_cast<const ::Akonadi::EntityTreeModel *>(cppSelf)->::Akonadi::EntityTreeModel::entityData(*cppArg0, cppArg1, cppArg2)
                    : const_cast<const ::Akonadi::EntityTreeModel *>(cppSelf)->entityData(*cppArg0, cppArg1, cppArg2);
                pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], &cppResult);
            }
            break;
        }
        case 1: // entityData(const Akonadi::Collection &collection, int column, int role) const
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"role", 2}};
                if (!Shiboken::parseKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                    || (pyArgs[2] != nullptr && !((pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2])))))) {
                    Py_XINCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "entityData", errInfo, SbkAkonadiCoreTypeStructs[SBK_Akonadi_EntityTreeModel_IDX]);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::Akonadi::Collection cppArg0_local;
            ::Akonadi::Collection *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            int cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            int cppArg2 = Qt::DisplayRole;
            if (pythonToCpp[2])
                pythonToCpp[2](pyArgs[2], &cppArg2);

            if (Shiboken::Errors::occurred() == nullptr) {
                // EntityTreeModel::entityData(const Akonadi::Collection&,int,int=)const->QVariant
                QVariant cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                    ? const_cast<const ::Akonadi::EntityTreeModel *>(cppSelf)->::Akonadi::EntityTreeModel::entityData(*cppArg0, cppArg1, cppArg2)
                    : const_cast<const ::Akonadi::EntityTreeModel *>(cppSelf)->entityData(*cppArg0, cppArg1, cppArg2);
                pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], &cppResult);
            }
            break;
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_EntityTreeModelFunc_entityHeaderData(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::EntityTreeModel *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_EntityTreeModel_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp[4];
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "entityHeaderData", 4, 4, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3])) == 0)
        return {};


    // Overloaded function decisor
    // 0: EntityTreeModel::entityHeaderData(int,Qt::Orientation,int,Akonadi::EntityTreeModel::HeaderGroup)const->QVariant
    if (numArgs == 4
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Enum::getConverter(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_Orientation_IDX]))), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2])))
        && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Enum::getConverter(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_EntityTreeModel_HeaderGroup_IDX]))), (pyArgs[3])))) {
        overloadId = 0; // EntityTreeModel::entityHeaderData(int,Qt::Orientation,int,Akonadi::EntityTreeModel::HeaderGroup)const->QVariant
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "entityHeaderData", SbkAkonadiCoreTypeStructs[SBK_Akonadi_EntityTreeModel_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::Qt::Orientation cppArg1 = static_cast< ::Qt::Orientation>(0);
        pythonToCpp[1](pyArgs[1], &cppArg1);
        int cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);
        ::Akonadi::EntityTreeModel::HeaderGroup cppArg3{Akonadi::EntityTreeModel::EntityTreeHeaders};
        pythonToCpp[3](pyArgs[3], &cppArg3);

        if (Shiboken::Errors::occurred() == nullptr) {
            // EntityTreeModel::entityHeaderData(int,Qt::Orientation,int,Akonadi::EntityTreeModel::HeaderGroup)const->QVariant
            QVariant cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? const_cast<const ::Akonadi::EntityTreeModel *>(cppSelf)->::Akonadi::EntityTreeModel::entityHeaderData(cppArg0, cppArg1, cppArg2, cppArg3)
                : const_cast<const ::Akonadi::EntityTreeModel *>(cppSelf)->entityHeaderData(cppArg0, cppArg1, cppArg2, cppArg3);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_EntityTreeModelFunc_fetchMore(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::EntityTreeModel *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_EntityTreeModel_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: QAbstractItemModel::fetchMore(const QModelIndex&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelIndex_IDX]), (pyArg)))) {
        overloadId = 0; // QAbstractItemModel::fetchMore(const QModelIndex&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "fetchMore", SbkAkonadiCoreTypeStructs[SBK_Akonadi_EntityTreeModel_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QModelIndex cppArg0_local;
        ::QModelIndex *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // QAbstractItemModel::fetchMore(const QModelIndex&)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::Akonadi::EntityTreeModel::fetchMore(*cppArg0)
                : cppSelf->fetchMore(*cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_Akonadi_EntityTreeModelFunc_flags(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::EntityTreeModel *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_EntityTreeModel_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: QAbstractItemModel::flags(const QModelIndex&)const->QFlags<Qt::ItemFlag>
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelIndex_IDX]), (pyArg)))) {
        overloadId = 0; // QAbstractItemModel::flags(const QModelIndex&)const->QFlags<Qt::ItemFlag>
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "flags", SbkAkonadiCoreTypeStructs[SBK_Akonadi_EntityTreeModel_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QModelIndex cppArg0_local;
        ::QModelIndex *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // QAbstractItemModel::flags(const QModelIndex&)const->QFlags<Qt::ItemFlag>
            QFlags<Qt::ItemFlag> cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? const_cast<const ::Akonadi::EntityTreeModel *>(cppSelf)->::Akonadi::EntityTreeModel::flags(*cppArg0)
                : const_cast<const ::Akonadi::EntityTreeModel *>(cppSelf)->flags(*cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Enum::getFlagsConverter(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_Qt_ItemFlag_IDX]))), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_EntityTreeModelFunc_hasChildren(PyObject *self, PyObject *args, [[maybe_unused]] PyObject *kwds)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::EntityTreeModel *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_EntityTreeModel_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 1));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "hasChildren", errInfo, SbkAkonadiCoreTypeStructs[SBK_Akonadi_EntityTreeModel_IDX]);

    if (PyArg_ParseTuple(args, "|O:hasChildren", &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QAbstractItemModel::hasChildren(const QModelIndex&=)const->bool
    if (numArgs == 0) {
        overloadId = 0; // hasChildren(QModelIndex)const
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelIndex_IDX]), (pyArgs[0])))) {
        overloadId = 0; // QAbstractItemModel::hasChildren(const QModelIndex&=)const->bool
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "hasChildren", SbkAkonadiCoreTypeStructs[SBK_Akonadi_EntityTreeModel_IDX]);

    // Call function/method
    {
        if (kwds != nullptr && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"parent", 0}};
            if (!Shiboken::parseKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                || (pyArgs[0] != nullptr && !((pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelIndex_IDX]), (pyArgs[0])))))) {
                Py_XINCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "hasChildren", errInfo, SbkAkonadiCoreTypeStructs[SBK_Akonadi_EntityTreeModel_IDX]);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QModelIndex cppArg0_local = QModelIndex();
        ::QModelIndex *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0]) {
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);
            }

        if (Shiboken::Errors::occurred() == nullptr) {
            // QAbstractItemModel::hasChildren(const QModelIndex&=)const->bool
            bool cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? const_cast<const ::Akonadi::EntityTreeModel *>(cppSelf)->::Akonadi::EntityTreeModel::hasChildren(*cppArg0)
                : const_cast<const ::Akonadi::EntityTreeModel *>(cppSelf)->hasChildren(*cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_EntityTreeModelFunc_headerData(PyObject *self, PyObject *args, [[maybe_unused]] PyObject *kwds)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::EntityTreeModel *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_EntityTreeModel_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 2, 3));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "headerData", errInfo, SbkAkonadiCoreTypeStructs[SBK_Akonadi_EntityTreeModel_IDX]);

    if (PyArg_ParseTuple(args, "|OOO:headerData", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QAbstractItemModel::headerData(int,Qt::Orientation,int=)const->QVariant
    if (numArgs >= 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Enum::getConverter(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_Orientation_IDX]))), (pyArgs[1])))) {
        if (numArgs == 2) {
            overloadId = 0; // headerData(int,Qt::Orientation,int)const
        } else if (numArgs >= 3
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2])))) {
            overloadId = 0; // QAbstractItemModel::headerData(int,Qt::Orientation,int=)const->QVariant
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "headerData", SbkAkonadiCoreTypeStructs[SBK_Akonadi_EntityTreeModel_IDX]);

    // Call function/method
    {
        if (kwds != nullptr && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"role", 2}};
            if (!Shiboken::parseKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                || (pyArgs[2] != nullptr && !((pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2])))))) {
                Py_XINCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "headerData", errInfo, SbkAkonadiCoreTypeStructs[SBK_Akonadi_EntityTreeModel_IDX]);
            }
        }
        int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::Qt::Orientation cppArg1 = static_cast< ::Qt::Orientation>(0);
        pythonToCpp[1](pyArgs[1], &cppArg1);
        int cppArg2 = Qt::DisplayRole;
        if (pythonToCpp[2])
            pythonToCpp[2](pyArgs[2], &cppArg2);

        if (Shiboken::Errors::occurred() == nullptr) {
            // QAbstractItemModel::headerData(int,Qt::Orientation,int=)const->QVariant
            QVariant cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? const_cast<const ::Akonadi::EntityTreeModel *>(cppSelf)->::Akonadi::EntityTreeModel::headerData(cppArg0, cppArg1, cppArg2)
                : const_cast<const ::Akonadi::EntityTreeModel *>(cppSelf)->headerData(cppArg0, cppArg1, cppArg2);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_EntityTreeModelFunc_includeRootCollection(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::EntityTreeModel *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_EntityTreeModel_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // EntityTreeModel::includeRootCollection()const->bool
        bool cppResult = const_cast<const ::Akonadi::EntityTreeModel *>(cppSelf)->includeRootCollection();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_EntityTreeModelFunc_index(PyObject *self, PyObject *args, [[maybe_unused]] PyObject *kwds)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::EntityTreeModel *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_EntityTreeModel_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 2, 3));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "index", errInfo, SbkAkonadiCoreTypeStructs[SBK_Akonadi_EntityTreeModel_IDX]);

    if (PyArg_ParseTuple(args, "|OOO:index", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QAbstractItemModel::index(int,int,const QModelIndex&=)const->QModelIndex
    if (numArgs >= 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))) {
        if (numArgs == 2) {
            overloadId = 0; // index(int,int,QModelIndex)const
        } else if (numArgs >= 3
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelIndex_IDX]), (pyArgs[2])))) {
            overloadId = 0; // QAbstractItemModel::index(int,int,const QModelIndex&=)const->QModelIndex
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "index", SbkAkonadiCoreTypeStructs[SBK_Akonadi_EntityTreeModel_IDX]);

    // Call function/method
    {
        if (kwds != nullptr && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"parent", 2}};
            if (!Shiboken::parseKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                || (pyArgs[2] != nullptr && !((pythonToCpp[2] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelIndex_IDX]), (pyArgs[2])))))) {
                Py_XINCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "index", errInfo, SbkAkonadiCoreTypeStructs[SBK_Akonadi_EntityTreeModel_IDX]);
            }
        }
        int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        int cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        if (!Shiboken::Object::isValid(pyArgs[2]))
            return {};
        ::QModelIndex cppArg2_local = QModelIndex();
        ::QModelIndex *cppArg2 = &cppArg2_local;
        if (pythonToCpp[2]) {
            if (pythonToCpp[2].isValue())
                pythonToCpp[2](pyArgs[2], &cppArg2_local);
            else
                pythonToCpp[2](pyArgs[2], &cppArg2);
            }

        if (Shiboken::Errors::occurred() == nullptr) {
            // QAbstractItemModel::index(int,int,const QModelIndex&=)const->QModelIndex
            QModelIndex cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? const_cast<const ::Akonadi::EntityTreeModel *>(cppSelf)->::Akonadi::EntityTreeModel::index(cppArg0, cppArg1, *cppArg2)
                : const_cast<const ::Akonadi::EntityTreeModel *>(cppSelf)->index(cppArg0, cppArg1, *cppArg2);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelIndex_IDX]), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_EntityTreeModelFunc_insertColumns(PyObject *self, PyObject *args, [[maybe_unused]] PyObject *kwds)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::EntityTreeModel *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_EntityTreeModel_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 2, 3));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "insertColumns", errInfo, SbkAkonadiCoreTypeStructs[SBK_Akonadi_EntityTreeModel_IDX]);

    if (PyArg_ParseTuple(args, "|OOO:insertColumns", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QAbstractItemModel::insertColumns(int,int,const QModelIndex&=)->bool
    if (numArgs >= 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))) {
        if (numArgs == 2) {
            overloadId = 0; // insertColumns(int,int,QModelIndex)
        } else if (numArgs >= 3
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelIndex_IDX]), (pyArgs[2])))) {
            overloadId = 0; // QAbstractItemModel::insertColumns(int,int,const QModelIndex&=)->bool
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "insertColumns", SbkAkonadiCoreTypeStructs[SBK_Akonadi_EntityTreeModel_IDX]);

    // Call function/method
    {
        Shiboken::Errors::setPrivateMethod("insertColumns(int column, int count, const QModelIndex &index)");
        return {};
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_EntityTreeModelFunc_insertRows(PyObject *self, PyObject *args, [[maybe_unused]] PyObject *kwds)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::EntityTreeModel *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_EntityTreeModel_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 2, 3));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "insertRows", errInfo, SbkAkonadiCoreTypeStructs[SBK_Akonadi_EntityTreeModel_IDX]);

    if (PyArg_ParseTuple(args, "|OOO:insertRows", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QAbstractItemModel::insertRows(int,int,const QModelIndex&=)->bool
    if (numArgs >= 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))) {
        if (numArgs == 2) {
            overloadId = 0; // insertRows(int,int,QModelIndex)
        } else if (numArgs >= 3
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelIndex_IDX]), (pyArgs[2])))) {
            overloadId = 0; // QAbstractItemModel::insertRows(int,int,const QModelIndex&=)->bool
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "insertRows", SbkAkonadiCoreTypeStructs[SBK_Akonadi_EntityTreeModel_IDX]);

    // Call function/method
    {
        Shiboken::Errors::setPrivateMethod("insertRows(int row, int count, const QModelIndex &index)");
        return {};
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_EntityTreeModelFunc_isCollectionPopulated(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::EntityTreeModel *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_EntityTreeModel_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: EntityTreeModel::isCollectionPopulated(long long)const->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<long long>(), (pyArg)))) {
        overloadId = 0; // EntityTreeModel::isCollectionPopulated(long long)const->bool
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "isCollectionPopulated", SbkAkonadiCoreTypeStructs[SBK_Akonadi_EntityTreeModel_IDX]);

    // Call function/method
    {
        long long cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // EntityTreeModel::isCollectionPopulated(long long)const->bool
            bool cppResult = const_cast<const ::Akonadi::EntityTreeModel *>(cppSelf)->isCollectionPopulated(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_EntityTreeModelFunc_isCollectionTreeFetched(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::EntityTreeModel *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_EntityTreeModel_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // EntityTreeModel::isCollectionTreeFetched()const->bool
        bool cppResult = const_cast<const ::Akonadi::EntityTreeModel *>(cppSelf)->isCollectionTreeFetched();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_EntityTreeModelFunc_isFullyPopulated(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::EntityTreeModel *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_EntityTreeModel_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // EntityTreeModel::isFullyPopulated()const->bool
        bool cppResult = const_cast<const ::Akonadi::EntityTreeModel *>(cppSelf)->isFullyPopulated();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_EntityTreeModelFunc_itemPopulationStrategy(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::EntityTreeModel *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_EntityTreeModel_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // EntityTreeModel::itemPopulationStrategy()const->Akonadi::EntityTreeModel::ItemPopulationStrategy
        Akonadi::EntityTreeModel::ItemPopulationStrategy cppResult = const_cast<const ::Akonadi::EntityTreeModel *>(cppSelf)->itemPopulationStrategy();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Enum::getConverter(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_EntityTreeModel_ItemPopulationStrategy_IDX]))), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_EntityTreeModelFunc_listFilter(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::EntityTreeModel *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_EntityTreeModel_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // EntityTreeModel::listFilter()const->Akonadi::CollectionFetchScope::ListFilter
        Akonadi::CollectionFetchScope::ListFilter cppResult = const_cast<const ::Akonadi::EntityTreeModel *>(cppSelf)->listFilter();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Enum::getConverter(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_CollectionFetchScope_ListFilter_IDX]))), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_EntityTreeModelFunc_match(PyObject *self, PyObject *args, [[maybe_unused]] PyObject *kwds)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::EntityTreeModel *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_EntityTreeModel_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp[5];
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 3, 5));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "match", errInfo, SbkAkonadiCoreTypeStructs[SBK_Akonadi_EntityTreeModel_IDX]);

    if (PyArg_ParseTuple(args, "|OOOOO:match", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3]), &(pyArgs[4])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QAbstractItemModel::match(const QModelIndex&,int,const QVariant&,int=,QFlags<Qt::MatchFlag>=)const->QList<QModelIndex>
    if (numArgs >= 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelIndex_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], (pyArgs[2])))) {
        if (numArgs == 3) {
            overloadId = 0; // match(QModelIndex,int,QVariant,int,QFlags<Qt::MatchFlag>)const
        } else if (numArgs >= 4
            && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[3])))) {
            if (numArgs == 4) {
                overloadId = 0; // match(QModelIndex,int,QVariant,int,QFlags<Qt::MatchFlag>)const
            } else if (numArgs >= 5
                && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Enum::getFlagsConverter(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_Qt_MatchFlag_IDX]))), (pyArgs[4])))) {
                overloadId = 0; // QAbstractItemModel::match(const QModelIndex&,int,const QVariant&,int=,QFlags<Qt::MatchFlag>=)const->QList<QModelIndex>
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "match", SbkAkonadiCoreTypeStructs[SBK_Akonadi_EntityTreeModel_IDX]);

    // Call function/method
    {
        if (kwds != nullptr && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[2] = {{"hits", 3}, {"flags", 4}};
            if (!Shiboken::parseKeywordArguments(kwds, mapping, 2, errInfo, pyArgs)
                || (pyArgs[3] != nullptr && !((pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[3])))))
                || (pyArgs[4] != nullptr && !((pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Enum::getFlagsConverter(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_Qt_MatchFlag_IDX]))), (pyArgs[4])))))) {
                Py_XINCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "match", errInfo, SbkAkonadiCoreTypeStructs[SBK_Akonadi_EntityTreeModel_IDX]);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QModelIndex cppArg0_local;
        ::QModelIndex *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0].isValue())
            pythonToCpp[0](pyArgs[0], &cppArg0_local);
        else
            pythonToCpp[0](pyArgs[0], &cppArg0);

        int cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        ::QVariant cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);
        int cppArg3 = 1;
        if (pythonToCpp[3])
            pythonToCpp[3](pyArgs[3], &cppArg3);
        ::QFlags<Qt::MatchFlag> cppArg4 = Qt::MatchFlags(Qt::MatchStartsWith | Qt::MatchWrap);
        if (pythonToCpp[4])
            pythonToCpp[4](pyArgs[4], &cppArg4);

        if (Shiboken::Errors::occurred() == nullptr) {
            // QAbstractItemModel::match(const QModelIndex&,int,const QVariant&,int=,QFlags<Qt::MatchFlag>=)const->QList<QModelIndex>
            QList<QModelIndex> cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? const_cast<const ::Akonadi::EntityTreeModel *>(cppSelf)->::Akonadi::EntityTreeModel::match(*cppArg0, cppArg1, cppArg2, cppArg3, cppArg4)
                : const_cast<const ::Akonadi::EntityTreeModel *>(cppSelf)->match(*cppArg0, cppArg1, cppArg2, cppArg3, cppArg4);
            pyResult = Shiboken::Conversions::copyToPython(SbkAkonadiCoreTypeConverters[SBK_AkonadiCore_QList_QModelIndex_IDX], &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_EntityTreeModelFunc_mimeData(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::EntityTreeModel *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_EntityTreeModel_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: QAbstractItemModel::mimeData(const QList<QModelIndex>&)const->QMimeData*
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkAkonadiCoreTypeConverters[SBK_AkonadiCore_QList_QModelIndex_IDX], (pyArg)))) {
        overloadId = 0; // QAbstractItemModel::mimeData(const QList<QModelIndex>&)const->QMimeData*
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "mimeData", SbkAkonadiCoreTypeStructs[SBK_Akonadi_EntityTreeModel_IDX]);

    // Call function/method
    {
        ::QList<QModelIndex> cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // QAbstractItemModel::mimeData(const QList<QModelIndex>&)const->QMimeData*
            QMimeData * cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? const_cast<const ::Akonadi::EntityTreeModel *>(cppSelf)->::Akonadi::EntityTreeModel::mimeData(cppArg0)
                : const_cast<const ::Akonadi::EntityTreeModel *>(cppSelf)->mimeData(cppArg0);
            pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMimeData_IDX]), cppResult);

            // Ownership transferences.
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_EntityTreeModelFunc_mimeTypes(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::EntityTreeModel *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_EntityTreeModel_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // QAbstractItemModel::mimeTypes()const->QStringList
        QStringList cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? const_cast<const ::Akonadi::EntityTreeModel *>(cppSelf)->::Akonadi::EntityTreeModel::mimeTypes()
            : const_cast<const ::Akonadi::EntityTreeModel *>(cppSelf)->mimeTypes();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_EntityTreeModelFunc_modelIndexForCollection([[maybe_unused]] PyObject *self, PyObject *args)
{
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "modelIndexForCollection", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static EntityTreeModel::modelIndexForCollection(const QAbstractItemModel*,const Akonadi::Collection&)->QModelIndex
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QAbstractItemModel_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Collection_IDX]), (pyArgs[1])))) {
        overloadId = 0; // static EntityTreeModel::modelIndexForCollection(const QAbstractItemModel*,const Akonadi::Collection&)->QModelIndex
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "modelIndexForCollection", SbkAkonadiCoreTypeStructs[SBK_Akonadi_EntityTreeModel_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QAbstractItemModel *cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::Akonadi::Collection cppArg1_local;
        ::Akonadi::Collection *cppArg1 = &cppArg1_local;
        if (pythonToCpp[1].isValue())
            pythonToCpp[1](pyArgs[1], &cppArg1_local);
        else
            pythonToCpp[1](pyArgs[1], &cppArg1);


        if (Shiboken::Errors::occurred() == nullptr) {
            // static EntityTreeModel::modelIndexForCollection(const QAbstractItemModel*,const Akonadi::Collection&)->QModelIndex
            QModelIndex cppResult = ::Akonadi::EntityTreeModel::modelIndexForCollection(cppArg0, *cppArg1);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelIndex_IDX]), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_EntityTreeModelFunc_modelIndexesForItem([[maybe_unused]] PyObject *self, PyObject *args)
{
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "modelIndexesForItem", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static EntityTreeModel::modelIndexesForItem(const QAbstractItemModel*,const Akonadi::Item&)->QList<QModelIndex>
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QAbstractItemModel_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Item_IDX]), (pyArgs[1])))) {
        overloadId = 0; // static EntityTreeModel::modelIndexesForItem(const QAbstractItemModel*,const Akonadi::Item&)->QList<QModelIndex>
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "modelIndexesForItem", SbkAkonadiCoreTypeStructs[SBK_Akonadi_EntityTreeModel_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QAbstractItemModel *cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::Akonadi::Item cppArg1_local;
        ::Akonadi::Item *cppArg1 = &cppArg1_local;
        if (pythonToCpp[1].isValue())
            pythonToCpp[1](pyArgs[1], &cppArg1_local);
        else
            pythonToCpp[1](pyArgs[1], &cppArg1);


        if (Shiboken::Errors::occurred() == nullptr) {
            // static EntityTreeModel::modelIndexesForItem(const QAbstractItemModel*,const Akonadi::Item&)->QList<QModelIndex>
            QList<QModelIndex> cppResult = ::Akonadi::EntityTreeModel::modelIndexesForItem(cppArg0, *cppArg1);
            pyResult = Shiboken::Conversions::copyToPython(SbkAkonadiCoreTypeConverters[SBK_AkonadiCore_QList_QModelIndex_IDX], &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_EntityTreeModelFunc_parent(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::EntityTreeModel *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_EntityTreeModel_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "parent", 0, 1, &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QAbstractItemModel::parent(const QModelIndex&)const->QModelIndex
    // 1: QObject::parent()const->QObject*
    if (numArgs == 0) {
        overloadId = 1; // parent()const
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelIndex_IDX]), (pyArgs[0])))) {
        overloadId = 0; // QAbstractItemModel::parent(const QModelIndex&)const->QModelIndex
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "parent", SbkAkonadiCoreTypeStructs[SBK_Akonadi_EntityTreeModel_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // parent(const QModelIndex &index) const
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QModelIndex cppArg0_local;
            ::QModelIndex *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QAbstractItemModel::parent(const QModelIndex&)const->QModelIndex
                QModelIndex cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                    ? const_cast<const ::Akonadi::EntityTreeModel *>(cppSelf)->::Akonadi::EntityTreeModel::parent(*cppArg0)
                    : const_cast<const ::Akonadi::EntityTreeModel *>(cppSelf)->parent(*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelIndex_IDX]), &cppResult);
            }
            break;
        }
        case 1: // parent() const
        {

            // QObject::parent()const->QObject*
            QObject * cppResult = const_cast<const ::QObject *>(reinterpret_cast<QObject *>(cppSelf))->parent();
            pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), cppResult);

            // Ownership transferences.
            break;
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_EntityTreeModelFunc_removeColumns(PyObject *self, PyObject *args, [[maybe_unused]] PyObject *kwds)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::EntityTreeModel *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_EntityTreeModel_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 2, 3));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "removeColumns", errInfo, SbkAkonadiCoreTypeStructs[SBK_Akonadi_EntityTreeModel_IDX]);

    if (PyArg_ParseTuple(args, "|OOO:removeColumns", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QAbstractItemModel::removeColumns(int,int,const QModelIndex&=)->bool
    if (numArgs >= 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))) {
        if (numArgs == 2) {
            overloadId = 0; // removeColumns(int,int,QModelIndex)
        } else if (numArgs >= 3
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelIndex_IDX]), (pyArgs[2])))) {
            overloadId = 0; // QAbstractItemModel::removeColumns(int,int,const QModelIndex&=)->bool
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "removeColumns", SbkAkonadiCoreTypeStructs[SBK_Akonadi_EntityTreeModel_IDX]);

    // Call function/method
    {
        Shiboken::Errors::setPrivateMethod("removeColumns(int column, int count, const QModelIndex &index)");
        return {};
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_EntityTreeModelFunc_removeRows(PyObject *self, PyObject *args, [[maybe_unused]] PyObject *kwds)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::EntityTreeModel *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_EntityTreeModel_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 2, 3));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "removeRows", errInfo, SbkAkonadiCoreTypeStructs[SBK_Akonadi_EntityTreeModel_IDX]);

    if (PyArg_ParseTuple(args, "|OOO:removeRows", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QAbstractItemModel::removeRows(int,int,const QModelIndex&=)->bool
    if (numArgs >= 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))) {
        if (numArgs == 2) {
            overloadId = 0; // removeRows(int,int,QModelIndex)
        } else if (numArgs >= 3
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelIndex_IDX]), (pyArgs[2])))) {
            overloadId = 0; // QAbstractItemModel::removeRows(int,int,const QModelIndex&=)->bool
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "removeRows", SbkAkonadiCoreTypeStructs[SBK_Akonadi_EntityTreeModel_IDX]);

    // Call function/method
    {
        Shiboken::Errors::setPrivateMethod("removeRows(int row, int count, const QModelIndex &index)");
        return {};
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_EntityTreeModelFunc_roleNames(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::EntityTreeModel *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_EntityTreeModel_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // QAbstractItemModel::roleNames()const->QHash<int,QByteArray>
        QHash<int,QByteArray> cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? const_cast<const ::Akonadi::EntityTreeModel *>(cppSelf)->::Akonadi::EntityTreeModel::roleNames()
            : const_cast<const ::Akonadi::EntityTreeModel *>(cppSelf)->roleNames();
        pyResult = Shiboken::Conversions::copyToPython(SbkAkonadiCoreTypeConverters[SBK_AkonadiCore_QHash_int_QByteArray_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_EntityTreeModelFunc_rootCollectionDisplayName(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::EntityTreeModel *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_EntityTreeModel_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // EntityTreeModel::rootCollectionDisplayName()const->QString
        QString cppResult = const_cast<const ::Akonadi::EntityTreeModel *>(cppSelf)->rootCollectionDisplayName();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_EntityTreeModelFunc_rowCount(PyObject *self, PyObject *args, [[maybe_unused]] PyObject *kwds)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::EntityTreeModel *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_EntityTreeModel_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 1));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "rowCount", errInfo, SbkAkonadiCoreTypeStructs[SBK_Akonadi_EntityTreeModel_IDX]);

    if (PyArg_ParseTuple(args, "|O:rowCount", &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QAbstractItemModel::rowCount(const QModelIndex&=)const->int
    if (numArgs == 0) {
        overloadId = 0; // rowCount(QModelIndex)const
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelIndex_IDX]), (pyArgs[0])))) {
        overloadId = 0; // QAbstractItemModel::rowCount(const QModelIndex&=)const->int
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "rowCount", SbkAkonadiCoreTypeStructs[SBK_Akonadi_EntityTreeModel_IDX]);

    // Call function/method
    {
        if (kwds != nullptr && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"parent", 0}};
            if (!Shiboken::parseKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                || (pyArgs[0] != nullptr && !((pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelIndex_IDX]), (pyArgs[0])))))) {
                Py_XINCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "rowCount", errInfo, SbkAkonadiCoreTypeStructs[SBK_Akonadi_EntityTreeModel_IDX]);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QModelIndex cppArg0_local = QModelIndex();
        ::QModelIndex *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0]) {
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);
            }

        if (Shiboken::Errors::occurred() == nullptr) {
            // QAbstractItemModel::rowCount(const QModelIndex&=)const->int
            int cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? const_cast<const ::Akonadi::EntityTreeModel *>(cppSelf)->::Akonadi::EntityTreeModel::rowCount(*cppArg0)
                : const_cast<const ::Akonadi::EntityTreeModel *>(cppSelf)->rowCount(*cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_EntityTreeModelFunc_setCollectionFetchStrategy(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::EntityTreeModel *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_EntityTreeModel_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: EntityTreeModel::setCollectionFetchStrategy(Akonadi::EntityTreeModel::CollectionFetchStrategy)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Enum::getConverter(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_EntityTreeModel_CollectionFetchStrategy_IDX]))), (pyArg)))) {
        overloadId = 0; // EntityTreeModel::setCollectionFetchStrategy(Akonadi::EntityTreeModel::CollectionFetchStrategy)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setCollectionFetchStrategy", SbkAkonadiCoreTypeStructs[SBK_Akonadi_EntityTreeModel_IDX]);

    // Call function/method
    {
        ::Akonadi::EntityTreeModel::CollectionFetchStrategy cppArg0{Akonadi::EntityTreeModel::FetchNoCollections};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // EntityTreeModel::setCollectionFetchStrategy(Akonadi::EntityTreeModel::CollectionFetchStrategy)
            cppSelf->setCollectionFetchStrategy(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_Akonadi_EntityTreeModelFunc_setCollectionMonitored(PyObject *self, PyObject *args, [[maybe_unused]] PyObject *kwds)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::EntityTreeModel *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_EntityTreeModel_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "setCollectionMonitored", errInfo, SbkAkonadiCoreTypeStructs[SBK_Akonadi_EntityTreeModel_IDX]);

    if (PyArg_ParseTuple(args, "|OO:setCollectionMonitored", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: EntityTreeModel::setCollectionMonitored(const Akonadi::Collection&,bool=)
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Collection_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // setCollectionMonitored(Akonadi::Collection,bool)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[1])))) {
            overloadId = 0; // EntityTreeModel::setCollectionMonitored(const Akonadi::Collection&,bool=)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setCollectionMonitored", SbkAkonadiCoreTypeStructs[SBK_Akonadi_EntityTreeModel_IDX]);

    // Call function/method
    {
        if (kwds != nullptr && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"monitored", 1}};
            if (!Shiboken::parseKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                || (pyArgs[1] != nullptr && !((pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[1])))))) {
                Py_XINCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "setCollectionMonitored", errInfo, SbkAkonadiCoreTypeStructs[SBK_Akonadi_EntityTreeModel_IDX]);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::Akonadi::Collection cppArg0_local;
        ::Akonadi::Collection *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0].isValue())
            pythonToCpp[0](pyArgs[0], &cppArg0_local);
        else
            pythonToCpp[0](pyArgs[0], &cppArg0);

        bool cppArg1 = true;
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // EntityTreeModel::setCollectionMonitored(const Akonadi::Collection&,bool=)
            cppSelf->setCollectionMonitored(*cppArg0, cppArg1);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_Akonadi_EntityTreeModelFunc_setCollectionsMonitored(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::EntityTreeModel *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_EntityTreeModel_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: EntityTreeModel::setCollectionsMonitored(const QList<Akonadi::Collection>&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkAkonadiCoreTypeConverters[SBK_AkonadiCore_QList_Akonadi_Collection_IDX], (pyArg)))) {
        overloadId = 0; // EntityTreeModel::setCollectionsMonitored(const QList<Akonadi::Collection>&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setCollectionsMonitored", SbkAkonadiCoreTypeStructs[SBK_Akonadi_EntityTreeModel_IDX]);

    // Call function/method
    {
        ::QList<Akonadi::Collection> cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // EntityTreeModel::setCollectionsMonitored(const QList<Akonadi::Collection>&)
            cppSelf->setCollectionsMonitored(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_Akonadi_EntityTreeModelFunc_setData(PyObject *self, PyObject *args, [[maybe_unused]] PyObject *kwds)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::EntityTreeModel *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_EntityTreeModel_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 2, 3));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "setData", errInfo, SbkAkonadiCoreTypeStructs[SBK_Akonadi_EntityTreeModel_IDX]);

    if (PyArg_ParseTuple(args, "|OOO:setData", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QAbstractItemModel::setData(const QModelIndex&,const QVariant&,int=)->bool
    if (numArgs >= 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelIndex_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], (pyArgs[1])))) {
        if (numArgs == 2) {
            overloadId = 0; // setData(QModelIndex,QVariant,int)
        } else if (numArgs >= 3
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2])))) {
            overloadId = 0; // QAbstractItemModel::setData(const QModelIndex&,const QVariant&,int=)->bool
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setData", SbkAkonadiCoreTypeStructs[SBK_Akonadi_EntityTreeModel_IDX]);

    // Call function/method
    {
        if (kwds != nullptr && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"role", 2}};
            if (!Shiboken::parseKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                || (pyArgs[2] != nullptr && !((pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2])))))) {
                Py_XINCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "setData", errInfo, SbkAkonadiCoreTypeStructs[SBK_Akonadi_EntityTreeModel_IDX]);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QModelIndex cppArg0_local;
        ::QModelIndex *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0].isValue())
            pythonToCpp[0](pyArgs[0], &cppArg0_local);
        else
            pythonToCpp[0](pyArgs[0], &cppArg0);

        ::QVariant cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        int cppArg2 = Qt::EditRole;
        if (pythonToCpp[2])
            pythonToCpp[2](pyArgs[2], &cppArg2);

        if (Shiboken::Errors::occurred() == nullptr) {
            // QAbstractItemModel::setData(const QModelIndex&,const QVariant&,int=)->bool
            bool cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::Akonadi::EntityTreeModel::setData(*cppArg0, cppArg1, cppArg2)
                : cppSelf->setData(*cppArg0, cppArg1, cppArg2);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_EntityTreeModelFunc_setIncludeRootCollection(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::EntityTreeModel *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_EntityTreeModel_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: EntityTreeModel::setIncludeRootCollection(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // EntityTreeModel::setIncludeRootCollection(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setIncludeRootCollection", SbkAkonadiCoreTypeStructs[SBK_Akonadi_EntityTreeModel_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // EntityTreeModel::setIncludeRootCollection(bool)
            cppSelf->setIncludeRootCollection(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_Akonadi_EntityTreeModelFunc_setItemPopulationStrategy(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::EntityTreeModel *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_EntityTreeModel_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: EntityTreeModel::setItemPopulationStrategy(Akonadi::EntityTreeModel::ItemPopulationStrategy)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Enum::getConverter(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_EntityTreeModel_ItemPopulationStrategy_IDX]))), (pyArg)))) {
        overloadId = 0; // EntityTreeModel::setItemPopulationStrategy(Akonadi::EntityTreeModel::ItemPopulationStrategy)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setItemPopulationStrategy", SbkAkonadiCoreTypeStructs[SBK_Akonadi_EntityTreeModel_IDX]);

    // Call function/method
    {
        ::Akonadi::EntityTreeModel::ItemPopulationStrategy cppArg0{Akonadi::EntityTreeModel::NoItemPopulation};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // EntityTreeModel::setItemPopulationStrategy(Akonadi::EntityTreeModel::ItemPopulationStrategy)
            cppSelf->setItemPopulationStrategy(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_Akonadi_EntityTreeModelFunc_setListFilter(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::EntityTreeModel *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_EntityTreeModel_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: EntityTreeModel::setListFilter(Akonadi::CollectionFetchScope::ListFilter)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Enum::getConverter(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_CollectionFetchScope_ListFilter_IDX]))), (pyArg)))) {
        overloadId = 0; // EntityTreeModel::setListFilter(Akonadi::CollectionFetchScope::ListFilter)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setListFilter", SbkAkonadiCoreTypeStructs[SBK_Akonadi_EntityTreeModel_IDX]);

    // Call function/method
    {
        ::Akonadi::CollectionFetchScope::ListFilter cppArg0{Akonadi::CollectionFetchScope::NoFilter};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // EntityTreeModel::setListFilter(Akonadi::CollectionFetchScope::ListFilter)
            cppSelf->setListFilter(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_Akonadi_EntityTreeModelFunc_setRootCollectionDisplayName(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::EntityTreeModel *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_EntityTreeModel_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: EntityTreeModel::setRootCollectionDisplayName(const QString&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // EntityTreeModel::setRootCollectionDisplayName(const QString&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setRootCollectionDisplayName", SbkAkonadiCoreTypeStructs[SBK_Akonadi_EntityTreeModel_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // EntityTreeModel::setRootCollectionDisplayName(const QString&)
            cppSelf->setRootCollectionDisplayName(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_Akonadi_EntityTreeModelFunc_setShowSystemEntities(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::EntityTreeModel *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_EntityTreeModel_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: EntityTreeModel::setShowSystemEntities(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // EntityTreeModel::setShowSystemEntities(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setShowSystemEntities", SbkAkonadiCoreTypeStructs[SBK_Akonadi_EntityTreeModel_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // EntityTreeModel::setShowSystemEntities(bool)
            cppSelf->setShowSystemEntities(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_Akonadi_EntityTreeModelFunc_supportedDropActions(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::EntityTreeModel *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_EntityTreeModel_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // QAbstractItemModel::supportedDropActions()const->QFlags<Qt::DropAction>
        QFlags<Qt::DropAction> cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? const_cast<const ::Akonadi::EntityTreeModel *>(cppSelf)->::Akonadi::EntityTreeModel::supportedDropActions()
            : const_cast<const ::Akonadi::EntityTreeModel *>(cppSelf)->supportedDropActions();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Enum::getFlagsConverter(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_Qt_DropAction_IDX]))), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_EntityTreeModelFunc_systemEntitiesShown(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::EntityTreeModel *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_EntityTreeModel_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // EntityTreeModel::systemEntitiesShown()const->bool
        bool cppResult = const_cast<const ::Akonadi::EntityTreeModel *>(cppSelf)->systemEntitiesShown();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_EntityTreeModelFunc_updatedCollection([[maybe_unused]] PyObject *self, PyObject *args)
{
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "updatedCollection", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static EntityTreeModel::updatedCollection(const QAbstractItemModel*,const Akonadi::Collection&)->Akonadi::Collection
    // 1: static EntityTreeModel::updatedCollection(const QAbstractItemModel*,qint64)->Akonadi::Collection
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QAbstractItemModel_IDX]), (pyArgs[0])))) {
        if (numArgs == 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qint64>(), (pyArgs[1])))) {
            overloadId = 1; // static EntityTreeModel::updatedCollection(const QAbstractItemModel*,qint64)->Akonadi::Collection
        } else if (numArgs == 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Collection_IDX]), (pyArgs[1])))) {
            overloadId = 0; // static EntityTreeModel::updatedCollection(const QAbstractItemModel*,const Akonadi::Collection&)->Akonadi::Collection
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "updatedCollection", SbkAkonadiCoreTypeStructs[SBK_Akonadi_EntityTreeModel_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // updatedCollection(const QAbstractItemModel *model, const Akonadi::Collection &col)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QAbstractItemModel *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::Akonadi::Collection cppArg1_local;
            ::Akonadi::Collection *cppArg1 = &cppArg1_local;
            if (pythonToCpp[1].isValue())
                pythonToCpp[1](pyArgs[1], &cppArg1_local);
            else
                pythonToCpp[1](pyArgs[1], &cppArg1);


            if (Shiboken::Errors::occurred() == nullptr) {
                // static EntityTreeModel::updatedCollection(const QAbstractItemModel*,const Akonadi::Collection&)->Akonadi::Collection
                Akonadi::Collection cppResult = ::Akonadi::EntityTreeModel::updatedCollection(cppArg0, *cppArg1);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Collection_IDX]), &cppResult);
            }
            break;
        }
        case 1: // updatedCollection(const QAbstractItemModel *model, qint64 collectionId)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QAbstractItemModel *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            qint64 cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // static EntityTreeModel::updatedCollection(const QAbstractItemModel*,qint64)->Akonadi::Collection
                Akonadi::Collection cppResult = ::Akonadi::EntityTreeModel::updatedCollection(cppArg0, cppArg1);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Collection_IDX]), &cppResult);
            }
            break;
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}


static const char *Sbk_Akonadi_EntityTreeModel_PropertyStrings[] = {
    nullptr // Sentinel
};

static const char *Sbk_Akonadi_EntityTreeModel_EnumFlagInfo[] = {
    "CollectionFetchStrategy:IntEnum",
    "FetchState:IntEnum",
    "HeaderGroup:IntEnum",
    "ItemPopulationStrategy:IntEnum",
    "Roles:IntEnum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_Akonadi_EntityTreeModel_methods[] = {
    {"canFetchMore", reinterpret_cast<PyCFunction>(Sbk_Akonadi_EntityTreeModelFunc_canFetchMore), METH_O, nullptr},
    {"clearAndReset", reinterpret_cast<PyCFunction>(Sbk_Akonadi_EntityTreeModelFunc_clearAndReset), METH_NOARGS, nullptr},
    {"collectionFetchStrategy", reinterpret_cast<PyCFunction>(Sbk_Akonadi_EntityTreeModelFunc_collectionFetchStrategy), METH_NOARGS, nullptr},
    {"columnCount", reinterpret_cast<PyCFunction>(Sbk_Akonadi_EntityTreeModelFunc_columnCount), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"data", reinterpret_cast<PyCFunction>(Sbk_Akonadi_EntityTreeModelFunc_data), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"dropMimeData", reinterpret_cast<PyCFunction>(Sbk_Akonadi_EntityTreeModelFunc_dropMimeData), METH_VARARGS, nullptr},
    {"entityColumnCount", reinterpret_cast<PyCFunction>(Sbk_Akonadi_EntityTreeModelFunc_entityColumnCount), METH_O, nullptr},
    {"entityData", reinterpret_cast<PyCFunction>(Sbk_Akonadi_EntityTreeModelFunc_entityData), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"entityHeaderData", reinterpret_cast<PyCFunction>(Sbk_Akonadi_EntityTreeModelFunc_entityHeaderData), METH_VARARGS, nullptr},
    {"fetchMore", reinterpret_cast<PyCFunction>(Sbk_Akonadi_EntityTreeModelFunc_fetchMore), METH_O, nullptr},
    {"flags", reinterpret_cast<PyCFunction>(Sbk_Akonadi_EntityTreeModelFunc_flags), METH_O, nullptr},
    {"hasChildren", reinterpret_cast<PyCFunction>(Sbk_Akonadi_EntityTreeModelFunc_hasChildren), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"headerData", reinterpret_cast<PyCFunction>(Sbk_Akonadi_EntityTreeModelFunc_headerData), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"includeRootCollection", reinterpret_cast<PyCFunction>(Sbk_Akonadi_EntityTreeModelFunc_includeRootCollection), METH_NOARGS, nullptr},
    {"index", reinterpret_cast<PyCFunction>(Sbk_Akonadi_EntityTreeModelFunc_index), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"insertColumns", reinterpret_cast<PyCFunction>(Sbk_Akonadi_EntityTreeModelFunc_insertColumns), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"insertRows", reinterpret_cast<PyCFunction>(Sbk_Akonadi_EntityTreeModelFunc_insertRows), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"isCollectionPopulated", reinterpret_cast<PyCFunction>(Sbk_Akonadi_EntityTreeModelFunc_isCollectionPopulated), METH_O, nullptr},
    {"isCollectionTreeFetched", reinterpret_cast<PyCFunction>(Sbk_Akonadi_EntityTreeModelFunc_isCollectionTreeFetched), METH_NOARGS, nullptr},
    {"isFullyPopulated", reinterpret_cast<PyCFunction>(Sbk_Akonadi_EntityTreeModelFunc_isFullyPopulated), METH_NOARGS, nullptr},
    {"itemPopulationStrategy", reinterpret_cast<PyCFunction>(Sbk_Akonadi_EntityTreeModelFunc_itemPopulationStrategy), METH_NOARGS, nullptr},
    {"listFilter", reinterpret_cast<PyCFunction>(Sbk_Akonadi_EntityTreeModelFunc_listFilter), METH_NOARGS, nullptr},
    {"match", reinterpret_cast<PyCFunction>(Sbk_Akonadi_EntityTreeModelFunc_match), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"mimeData", reinterpret_cast<PyCFunction>(Sbk_Akonadi_EntityTreeModelFunc_mimeData), METH_O, nullptr},
    {"mimeTypes", reinterpret_cast<PyCFunction>(Sbk_Akonadi_EntityTreeModelFunc_mimeTypes), METH_NOARGS, nullptr},
    {"modelIndexForCollection", reinterpret_cast<PyCFunction>(Sbk_Akonadi_EntityTreeModelFunc_modelIndexForCollection), METH_VARARGS|METH_STATIC, nullptr},
    {"modelIndexesForItem", reinterpret_cast<PyCFunction>(Sbk_Akonadi_EntityTreeModelFunc_modelIndexesForItem), METH_VARARGS|METH_STATIC, nullptr},
    {"parent", reinterpret_cast<PyCFunction>(Sbk_Akonadi_EntityTreeModelFunc_parent), METH_VARARGS, nullptr},
    {"removeColumns", reinterpret_cast<PyCFunction>(Sbk_Akonadi_EntityTreeModelFunc_removeColumns), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"removeRows", reinterpret_cast<PyCFunction>(Sbk_Akonadi_EntityTreeModelFunc_removeRows), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"roleNames", reinterpret_cast<PyCFunction>(Sbk_Akonadi_EntityTreeModelFunc_roleNames), METH_NOARGS, nullptr},
    {"rootCollectionDisplayName", reinterpret_cast<PyCFunction>(Sbk_Akonadi_EntityTreeModelFunc_rootCollectionDisplayName), METH_NOARGS, nullptr},
    {"rowCount", reinterpret_cast<PyCFunction>(Sbk_Akonadi_EntityTreeModelFunc_rowCount), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"setCollectionFetchStrategy", reinterpret_cast<PyCFunction>(Sbk_Akonadi_EntityTreeModelFunc_setCollectionFetchStrategy), METH_O, nullptr},
    {"setCollectionMonitored", reinterpret_cast<PyCFunction>(Sbk_Akonadi_EntityTreeModelFunc_setCollectionMonitored), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"setCollectionsMonitored", reinterpret_cast<PyCFunction>(Sbk_Akonadi_EntityTreeModelFunc_setCollectionsMonitored), METH_O, nullptr},
    {"setData", reinterpret_cast<PyCFunction>(Sbk_Akonadi_EntityTreeModelFunc_setData), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"setIncludeRootCollection", reinterpret_cast<PyCFunction>(Sbk_Akonadi_EntityTreeModelFunc_setIncludeRootCollection), METH_O, nullptr},
    {"setItemPopulationStrategy", reinterpret_cast<PyCFunction>(Sbk_Akonadi_EntityTreeModelFunc_setItemPopulationStrategy), METH_O, nullptr},
    {"setListFilter", reinterpret_cast<PyCFunction>(Sbk_Akonadi_EntityTreeModelFunc_setListFilter), METH_O, nullptr},
    {"setRootCollectionDisplayName", reinterpret_cast<PyCFunction>(Sbk_Akonadi_EntityTreeModelFunc_setRootCollectionDisplayName), METH_O, nullptr},
    {"setShowSystemEntities", reinterpret_cast<PyCFunction>(Sbk_Akonadi_EntityTreeModelFunc_setShowSystemEntities), METH_O, nullptr},
    {"supportedDropActions", reinterpret_cast<PyCFunction>(Sbk_Akonadi_EntityTreeModelFunc_supportedDropActions), METH_NOARGS, nullptr},
    {"systemEntitiesShown", reinterpret_cast<PyCFunction>(Sbk_Akonadi_EntityTreeModelFunc_systemEntitiesShown), METH_NOARGS, nullptr},
    {"updatedCollection", reinterpret_cast<PyCFunction>(Sbk_Akonadi_EntityTreeModelFunc_updatedCollection), METH_VARARGS|METH_STATIC, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_Akonadi_EntityTreeModel_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::Akonadi::EntityTreeModel *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_EntityTreeModel_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<EntityTreeModelWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    Shiboken::AutoDecRef pp(reinterpret_cast<PyObject *>(PySide::Property::getObject(self, name)));
    if (!pp.isNull())
        return PySide::Property::setValue(reinterpret_cast<PySideProperty *>(pp.object()), self, value);
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_Akonadi_EntityTreeModel_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PyType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_Akonadi_EntityTreeModel_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PyType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}

// Class Definition -----------------------------------------------
extern "C" {

static PyType_Slot Sbk_Akonadi_EntityTreeModel_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_Akonadi_EntityTreeModel_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_Akonadi_EntityTreeModel_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_Akonadi_EntityTreeModel_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_Akonadi_EntityTreeModel_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_Akonadi_EntityTreeModel_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_Akonadi_EntityTreeModel_spec = {
    "1:AkonadiCore.Akonadi.EntityTreeModel",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_Akonadi_EntityTreeModel_slots
};

} //extern "C"

static void *Sbk_Akonadi_EntityTreeModel_typeDiscovery([[maybe_unused]] void *cptr, [[maybe_unused]] PyTypeObject *instanceType)
{
    if (instanceType == Shiboken::SbkType< ::QObject >())
        return dynamic_cast< ::Akonadi::EntityTreeModel *>(reinterpret_cast< ::QObject *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_Akonadi_EntityTreeModel_Roles(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::Akonadi::EntityTreeModel::Roles>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::Akonadi::EntityTreeModel::Roles *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_Akonadi_EntityTreeModel_Roles_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_EntityTreeModel_Roles_IDX])))
        return Enum_PythonToCpp_Akonadi_EntityTreeModel_Roles;
    return {};
}

static PyObject *Akonadi_EntityTreeModel_Roles_CppToPython_Enum(PyTypeObject *pyType, const void *cppIn)
{
    using IntType = std::underlying_type_t<::Akonadi::EntityTreeModel::Roles>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::Akonadi::EntityTreeModel::Roles *>(cppIn));
    return Shiboken::Enum::newItem(pyType, castCppIn);

}

static void Enum_PythonToCpp_Akonadi_EntityTreeModel_FetchState(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::Akonadi::EntityTreeModel::FetchState>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::Akonadi::EntityTreeModel::FetchState *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_Akonadi_EntityTreeModel_FetchState_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_EntityTreeModel_FetchState_IDX])))
        return Enum_PythonToCpp_Akonadi_EntityTreeModel_FetchState;
    return {};
}

static PyObject *Akonadi_EntityTreeModel_FetchState_CppToPython_Enum(PyTypeObject *pyType, const void *cppIn)
{
    using IntType = std::underlying_type_t<::Akonadi::EntityTreeModel::FetchState>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::Akonadi::EntityTreeModel::FetchState *>(cppIn));
    return Shiboken::Enum::newItem(pyType, castCppIn);

}

static void Enum_PythonToCpp_Akonadi_EntityTreeModel_HeaderGroup(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::Akonadi::EntityTreeModel::HeaderGroup>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::Akonadi::EntityTreeModel::HeaderGroup *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_Akonadi_EntityTreeModel_HeaderGroup_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_EntityTreeModel_HeaderGroup_IDX])))
        return Enum_PythonToCpp_Akonadi_EntityTreeModel_HeaderGroup;
    return {};
}

static PyObject *Akonadi_EntityTreeModel_HeaderGroup_CppToPython_Enum(PyTypeObject *pyType, const void *cppIn)
{
    using IntType = std::underlying_type_t<::Akonadi::EntityTreeModel::HeaderGroup>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::Akonadi::EntityTreeModel::HeaderGroup *>(cppIn));
    return Shiboken::Enum::newItem(pyType, castCppIn);

}

static void Enum_PythonToCpp_Akonadi_EntityTreeModel_ItemPopulationStrategy(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::Akonadi::EntityTreeModel::ItemPopulationStrategy>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::Akonadi::EntityTreeModel::ItemPopulationStrategy *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_Akonadi_EntityTreeModel_ItemPopulationStrategy_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_EntityTreeModel_ItemPopulationStrategy_IDX])))
        return Enum_PythonToCpp_Akonadi_EntityTreeModel_ItemPopulationStrategy;
    return {};
}

static PyObject *Akonadi_EntityTreeModel_ItemPopulationStrategy_CppToPython_Enum(PyTypeObject *pyType, const void *cppIn)
{
    using IntType = std::underlying_type_t<::Akonadi::EntityTreeModel::ItemPopulationStrategy>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::Akonadi::EntityTreeModel::ItemPopulationStrategy *>(cppIn));
    return Shiboken::Enum::newItem(pyType, castCppIn);

}

static void Enum_PythonToCpp_Akonadi_EntityTreeModel_CollectionFetchStrategy(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::Akonadi::EntityTreeModel::CollectionFetchStrategy>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::Akonadi::EntityTreeModel::CollectionFetchStrategy *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_Akonadi_EntityTreeModel_CollectionFetchStrategy_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_EntityTreeModel_CollectionFetchStrategy_IDX])))
        return Enum_PythonToCpp_Akonadi_EntityTreeModel_CollectionFetchStrategy;
    return {};
}

static PyObject *Akonadi_EntityTreeModel_CollectionFetchStrategy_CppToPython_Enum(PyTypeObject *pyType, const void *cppIn)
{
    using IntType = std::underlying_type_t<::Akonadi::EntityTreeModel::CollectionFetchStrategy>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::Akonadi::EntityTreeModel::CollectionFetchStrategy *>(cppIn));
    return Shiboken::Enum::newItem(pyType, castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void EntityTreeModel_PythonToCpp_EntityTreeModel_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_Akonadi_EntityTreeModel_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_EntityTreeModel_PythonToCpp_EntityTreeModel_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_Akonadi_EntityTreeModel_TypeF()))
        return EntityTreeModel_PythonToCpp_EntityTreeModel_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *EntityTreeModel_PTR_CppToPython_EntityTreeModel(const void *cppIn)
{
    return PySide::getWrapperForQObject(reinterpret_cast<::Akonadi::EntityTreeModel *>(const_cast<void *>(cppIn)), Sbk_Akonadi_EntityTreeModel_TypeF());

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *Akonadi_EntityTreeModel_SignatureStrings[] = {
    "AkonadiCore.Akonadi.EntityTreeModel(self,monitor:AkonadiCore.Akonadi.Monitor,parent:PySide6.QtCore.QObject=nullptr)",
    "AkonadiCore.Akonadi.EntityTreeModel.canFetchMore(self,parent:typing.Union[PySide6.QtCore.QModelIndex, PySide6.QtCore.QPersistentModelIndex])->bool",
    "AkonadiCore.Akonadi.EntityTreeModel.clearAndReset(self)",
    "AkonadiCore.Akonadi.EntityTreeModel.collectionFetchStrategy(self)->AkonadiCore.Akonadi.EntityTreeModel.CollectionFetchStrategy",
    "AkonadiCore.Akonadi.EntityTreeModel.columnCount(self,parent:typing.Union[PySide6.QtCore.QModelIndex, PySide6.QtCore.QPersistentModelIndex]=QModelIndex())->int",
    "AkonadiCore.Akonadi.EntityTreeModel.data(self,index:typing.Union[PySide6.QtCore.QModelIndex, PySide6.QtCore.QPersistentModelIndex],role:int=Qt.DisplayRole)->QVariant",
    "AkonadiCore.Akonadi.EntityTreeModel.dropMimeData(self,data:PySide6.QtCore.QMimeData,action:PySide6.QtCore.Qt.DropAction,row:int,column:int,parent:typing.Union[PySide6.QtCore.QModelIndex, PySide6.QtCore.QPersistentModelIndex])->bool",
    "AkonadiCore.Akonadi.EntityTreeModel.entityColumnCount(self,headerGroup:AkonadiCore.Akonadi.EntityTreeModel.HeaderGroup)->int",
    "1:AkonadiCore.Akonadi.EntityTreeModel.entityData(self,item:AkonadiCore.Akonadi.Item,column:int,role:int=Qt.DisplayRole)->QVariant",
    "0:AkonadiCore.Akonadi.EntityTreeModel.entityData(self,collection:AkonadiCore.Akonadi.Collection,column:int,role:int=Qt.DisplayRole)->QVariant",
    "AkonadiCore.Akonadi.EntityTreeModel.entityHeaderData(self,section:int,orientation:PySide6.QtCore.Qt.Orientation,role:int,headerGroup:AkonadiCore.Akonadi.EntityTreeModel.HeaderGroup)->QVariant",
    "AkonadiCore.Akonadi.EntityTreeModel.fetchMore(self,parent:typing.Union[PySide6.QtCore.QModelIndex, PySide6.QtCore.QPersistentModelIndex])",
    "AkonadiCore.Akonadi.EntityTreeModel.flags(self,index:typing.Union[PySide6.QtCore.QModelIndex, PySide6.QtCore.QPersistentModelIndex])->PySide6.QtCore.Qt.ItemFlag",
    "AkonadiCore.Akonadi.EntityTreeModel.hasChildren(self,parent:typing.Union[PySide6.QtCore.QModelIndex, PySide6.QtCore.QPersistentModelIndex]=QModelIndex())->bool",
    "AkonadiCore.Akonadi.EntityTreeModel.headerData(self,section:int,orientation:PySide6.QtCore.Qt.Orientation,role:int=Qt.DisplayRole)->QVariant",
    "AkonadiCore.Akonadi.EntityTreeModel.includeRootCollection(self)->bool",
    "AkonadiCore.Akonadi.EntityTreeModel.index(self,row:int,column:int,parent:typing.Union[PySide6.QtCore.QModelIndex, PySide6.QtCore.QPersistentModelIndex]=QModelIndex())->PySide6.QtCore.QModelIndex",
    "AkonadiCore.Akonadi.EntityTreeModel.insertColumns(self,column:int,count:int,index:typing.Union[PySide6.QtCore.QModelIndex, PySide6.QtCore.QPersistentModelIndex]=QModelIndex())->bool",
    "AkonadiCore.Akonadi.EntityTreeModel.insertRows(self,row:int,count:int,index:typing.Union[PySide6.QtCore.QModelIndex, PySide6.QtCore.QPersistentModelIndex]=QModelIndex())->bool",
    "AkonadiCore.Akonadi.EntityTreeModel.isCollectionPopulated(self,arg__1:long long)->bool",
    "AkonadiCore.Akonadi.EntityTreeModel.isCollectionTreeFetched(self)->bool",
    "AkonadiCore.Akonadi.EntityTreeModel.isFullyPopulated(self)->bool",
    "AkonadiCore.Akonadi.EntityTreeModel.itemPopulationStrategy(self)->AkonadiCore.Akonadi.EntityTreeModel.ItemPopulationStrategy",
    "AkonadiCore.Akonadi.EntityTreeModel.listFilter(self)->AkonadiCore.Akonadi.CollectionFetchScope.ListFilter",
    "AkonadiCore.Akonadi.EntityTreeModel.match(self,start:typing.Union[PySide6.QtCore.QModelIndex, PySide6.QtCore.QPersistentModelIndex],role:int,value:QVariant,hits:int=1,flags:PySide6.QtCore.Qt.MatchFlag=Qt.MatchFlags(Qt.MatchStartsWith | Qt.MatchWrap))->QList[PySide6.QtCore.QModelIndex]",
    "AkonadiCore.Akonadi.EntityTreeModel.mimeData(self,indexes:QList[PySide6.QtCore.QModelIndex])->PySide6.QtCore.QMimeData",
    "AkonadiCore.Akonadi.EntityTreeModel.mimeTypes(self)->QStringList",
    "AkonadiCore.Akonadi.EntityTreeModel.modelIndexForCollection(model:PySide6.QtCore.QAbstractItemModel,collection:AkonadiCore.Akonadi.Collection)->PySide6.QtCore.QModelIndex",
    "AkonadiCore.Akonadi.EntityTreeModel.modelIndexesForItem(model:PySide6.QtCore.QAbstractItemModel,item:AkonadiCore.Akonadi.Item)->QList[PySide6.QtCore.QModelIndex]",
    "1:AkonadiCore.Akonadi.EntityTreeModel.parent(self,index:typing.Union[PySide6.QtCore.QModelIndex, PySide6.QtCore.QPersistentModelIndex])->PySide6.QtCore.QModelIndex",
    "0:AkonadiCore.Akonadi.EntityTreeModel.parent(self)->PySide6.QtCore.QObject",
    "AkonadiCore.Akonadi.EntityTreeModel.removeColumns(self,column:int,count:int,index:typing.Union[PySide6.QtCore.QModelIndex, PySide6.QtCore.QPersistentModelIndex]=QModelIndex())->bool",
    "AkonadiCore.Akonadi.EntityTreeModel.removeRows(self,row:int,count:int,index:typing.Union[PySide6.QtCore.QModelIndex, PySide6.QtCore.QPersistentModelIndex]=QModelIndex())->bool",
    "AkonadiCore.Akonadi.EntityTreeModel.roleNames(self)->QHash[int, PySide6.QtCore.QByteArray]",
    "AkonadiCore.Akonadi.EntityTreeModel.rootCollectionDisplayName(self)->QString",
    "AkonadiCore.Akonadi.EntityTreeModel.rowCount(self,parent:typing.Union[PySide6.QtCore.QModelIndex, PySide6.QtCore.QPersistentModelIndex]=QModelIndex())->int",
    "AkonadiCore.Akonadi.EntityTreeModel.setCollectionFetchStrategy(self,strategy:AkonadiCore.Akonadi.EntityTreeModel.CollectionFetchStrategy)",
    "AkonadiCore.Akonadi.EntityTreeModel.setCollectionMonitored(self,col:AkonadiCore.Akonadi.Collection,monitored:bool=true)",
    "AkonadiCore.Akonadi.EntityTreeModel.setCollectionsMonitored(self,collections:QList[AkonadiCore.Akonadi.Collection])",
    "AkonadiCore.Akonadi.EntityTreeModel.setData(self,index:typing.Union[PySide6.QtCore.QModelIndex, PySide6.QtCore.QPersistentModelIndex],value:QVariant,role:int=Qt.EditRole)->bool",
    "AkonadiCore.Akonadi.EntityTreeModel.setIncludeRootCollection(self,include:bool)",
    "AkonadiCore.Akonadi.EntityTreeModel.setItemPopulationStrategy(self,strategy:AkonadiCore.Akonadi.EntityTreeModel.ItemPopulationStrategy)",
    "AkonadiCore.Akonadi.EntityTreeModel.setListFilter(self,filter:AkonadiCore.Akonadi.CollectionFetchScope.ListFilter)",
    "AkonadiCore.Akonadi.EntityTreeModel.setRootCollectionDisplayName(self,name:QString)",
    "AkonadiCore.Akonadi.EntityTreeModel.setShowSystemEntities(self,show:bool)",
    "AkonadiCore.Akonadi.EntityTreeModel.supportedDropActions(self)->PySide6.QtCore.Qt.DropAction",
    "AkonadiCore.Akonadi.EntityTreeModel.systemEntitiesShown(self)->bool",
    "1:AkonadiCore.Akonadi.EntityTreeModel.updatedCollection(model:PySide6.QtCore.QAbstractItemModel,col:AkonadiCore.Akonadi.Collection)->AkonadiCore.Akonadi.Collection",
    "0:AkonadiCore.Akonadi.EntityTreeModel.updatedCollection(model:PySide6.QtCore.QAbstractItemModel,collectionId:qint64)->AkonadiCore.Akonadi.Collection",
    nullptr}; // Sentinel
#else
static constexpr size_t Akonadi_EntityTreeModel_SignatureByteSize = 970;
static constexpr uint8_t Akonadi_EntityTreeModel_SignatureBytes[970] = {
    0x78, 0xda, 0xd5, 0x98, 0x5f, 0x6f, 0xd3, 0x30, 0x10, 0xc0, 0xdf, 0xf9, 0x14, 0x7b, 0xdc, 0xa4,
    0x50, 0x31, 0x09, 0xf1, 0x10, 0xa9, 0x48, 0xa5, 0xa3, 0x50, 0x89, 0xc2, 0xda, 0xf2, 0xe7, 0x01,
    0x4d, 0xc8, 0x6b, 0x6e, 0x8d, 0xc1, 0xb1, 0x83, 0xed, 0x30, 0x22, 0xf1, 0xe1, 0x39, 0x3b, 0x49,
    0x93, 0xb6, 0x69, 0x7b, 0x6d, 0xe9, 0x80, 0x97, 0x28, 0x89, 0x7d, 0x77, 0x3f, 0x9f, 0xcf, 0xe7,
    0xb3, 0x7b, 0xdf, 0x94, 0x64, 0x11, 0xef, 0x2b, 0x0d, 0x9d, 0x5e, 0xf1, 0xde, 0x79, 0x29, 0x2d,
    0xb7, 0xf9, 0x7b, 0x0d, 0x30, 0x52, 0x11, 0x88, 0x73, 0x03, 0xe2, 0x2e, 0x48, 0x94, 0xe4, 0x56,
    0xe9, 0xb0, 0xd7, 0x22, 0x30, 0x2a, 0xda, 0x82, 0x94, 0x69, 0x90, 0x36, 0xbc, 0xce, 0xa7, 0x3c,
    0x82, 0x67, 0x9d, 0xb1, 0xf5, 0xbd, 0xc6, 0xef, 0x6e, 0xbf, 0xc2, 0xcc, 0x76, 0x65, 0x26, 0x44,
    0x6a, 0xf5, 0xc5, 0xa3, 0xde, 0x6e, 0x9b, 0x9d, 0x19, 0x93, 0x03, 0xb0, 0xb3, 0x78, 0x84, 0x9d,
    0x0a, 0x80, 0x52, 0xb9, 0xcd, 0x53, 0x2e, 0xe7, 0x9d, 0x0f, 0x92, 0x2b, 0xf9, 0x79, 0xd5, 0x92,
    0x97, 0x1d, 0xca, 0x08, 0x7e, 0x06, 0x67, 0xab, 0x6d, 0xd7, 0xa0, 0x0d, 0x37, 0x16, 0x75, 0xd4,
    0xbd, 0x6e, 0x2e, 0x1e, 0x3f, 0xbf, 0x55, 0x4a, 0xd0, 0x90, 0x04, 0x30, 0xdd, 0x93, 0xd1, 0x04,
    0x0c, 0x58, 0xcf, 0x44, 0x1c, 0x8a, 0x12, 0x02, 0xc7, 0x8f, 0xbc, 0x7e, 0x44, 0x53, 0xab, 0x99,
    0x85, 0x79, 0x5e, 0x68, 0x78, 0xfc, 0x9c, 0xa2, 0xa2, 0xdf, 0xae, 0x82, 0x6a, 0x3e, 0x4b, 0x64,
    0x5f, 0x65, 0xd2, 0x9e, 0xd0, 0x91, 0xdd, 0x86, 0xc8, 0xf9, 0x05, 0x0e, 0x8b, 0x4b, 0x4b, 0xc2,
    0x8b, 0x98, 0x65, 0x05, 0x17, 0x77, 0xb2, 0x7f, 0x18, 0x2b, 0xd0, 0x4a, 0x40, 0x88, 0x2c, 0xdd,
    0xb1, 0xed, 0x5c, 0x71, 0x93, 0x0a, 0x96, 0x4f, 0xf0, 0x17, 0x02, 0x8e, 0x3f, 0x32, 0xcd, 0x19,
    0x95, 0x52, 0xab, 0x74, 0xc4, 0x13, 0xb8, 0x5a, 0xd0, 0x3a, 0xee, 0xb5, 0x48, 0xaf, 0xba, 0x04,
    0xcc, 0x4f, 0xd6, 0x5a, 0x3b, 0x32, 0xa0, 0xa2, 0x9e, 0x6f, 0x44, 0xb4, 0x7b, 0x47, 0x16, 0x14,
    0x13, 0xe4, 0x5f, 0xff, 0x7a, 0x8c, 0x83, 0xff, 0xee, 0xaf, 0x86, 0x4c, 0x0c, 0x2c, 0x02, 0xfd,
    0x4a, 0xab, 0x2c, 0x0d, 0x29, 0x6a, 0x5e, 0xd7, 0xfd, 0xcb, 0x50, 0xb8, 0x0c, 0xe9, 0xe6, 0x6b,
    0x27, 0x73, 0x0b, 0x49, 0xab, 0xe0, 0x10, 0x1b, 0x9a, 0x8e, 0x23, 0x4c, 0xf3, 0x93, 0x83, 0x08,
    0xea, 0xc5, 0xdb, 0x2a, 0x5e, 0x2f, 0xcc, 0x3d, 0x69, 0xe8, 0x2c, 0x85, 0x2f, 0x6b, 0x22, 0x53,
    0xe2, 0x38, 0x43, 0x4a, 0x73, 0xec, 0xc4, 0x36, 0xc4, 0xda, 0xbb, 0xba, 0x75, 0x81, 0x74, 0xe4,
    0x54, 0xee, 0xc5, 0x7f, 0xf7, 0x10, 0x09, 0x9c, 0x46, 0x22, 0xd8, 0xdc, 0x9c, 0x2e, 0xcb, 0xa0,
    0x63, 0xd6, 0xbd, 0xef, 0x42, 0x74, 0x80, 0x76, 0x49, 0x80, 0x31, 0x33, 0xfd, 0x98, 0x8b, 0x08,
    0x3d, 0xf4, 0x90, 0x49, 0x9a, 0x9c, 0x17, 0xe2, 0x3f, 0x1a, 0x84, 0x47, 0xae, 0x0b, 0x2e, 0x67,
    0x22, 0x8b, 0x60, 0xa2, 0x94, 0xad, 0xd7, 0x5f, 0xb5, 0x9d, 0x92, 0x87, 0xe4, 0x03, 0xa1, 0x18,
    0xcd, 0x43, 0x65, 0xe2, 0x35, 0xff, 0x6f, 0xd6, 0x48, 0x1c, 0x82, 0x01, 0x6d, 0x8b, 0x6c, 0x6d,
    0x16, 0xf9, 0xaa, 0x1a, 0xc2, 0xcc, 0xe5, 0x6f, 0xff, 0x76, 0x8a, 0x98, 0x3f, 0x3c, 0x96, 0x0a,
    0xea, 0x89, 0xba, 0x37, 0xab, 0xde, 0xff, 0x47, 0x79, 0x4d, 0x1d, 0x65, 0xd7, 0x2a, 0xcd, 0x04,
    0xd6, 0x5e, 0x51, 0x81, 0xce, 0xf4, 0xfc, 0xcb, 0x97, 0xcb, 0x50, 0x28, 0x39, 0x3f, 0x73, 0x8f,
    0x43, 0xd5, 0xba, 0xbf, 0xbe, 0xb2, 0x2b, 0x15, 0xef, 0xa7, 0x67, 0x80, 0x85, 0x75, 0xbe, 0x4c,
    0xb6, 0x97, 0x02, 0x4c, 0x54, 0xa5, 0x34, 0xa2, 0x1c, 0x52, 0x9e, 0x0e, 0x5b, 0x35, 0x90, 0x8c,
    0x0b, 0x9c, 0xa8, 0x01, 0x17, 0x16, 0xf4, 0x36, 0x83, 0xab, 0xf5, 0xef, 0x4c, 0xa5, 0xd0, 0x79,
    0xb3, 0x10, 0x25, 0x59, 0x4a, 0x18, 0x4a, 0x96, 0xd9, 0xcb, 0x32, 0x6d, 0x4f, 0x55, 0x69, 0x06,
    0x3f, 0x98, 0xc8, 0x20, 0xac, 0x32, 0x5a, 0x10, 0x73, 0x6b, 0x7c, 0xd2, 0xbb, 0x0c, 0xfc, 0x36,
    0xd4, 0x92, 0x23, 0x47, 0x0e, 0xcd, 0xed, 0x15, 0xdd, 0xe6, 0x87, 0x39, 0xaf, 0xbe, 0xa6, 0x8e,
    0xd7, 0x7c, 0xe2, 0x36, 0x3e, 0xfb, 0x75, 0x56, 0xfd, 0xfc, 0xa4, 0x59, 0xea, 0xe2, 0x78, 0xec,
    0xfc, 0xb0, 0x85, 0xff, 0x86, 0xe6, 0x9d, 0xa5, 0xe2, 0xd6, 0x2f, 0x40, 0x30, 0xe1, 0x4e, 0xdd,
    0x6d, 0x39, 0xac, 0xd4, 0x44, 0x36, 0xfb, 0x3e, 0x4f, 0xc1, 0x54, 0xb3, 0x3f, 0xc6, 0xe8, 0xc1,
    0x59, 0x71, 0x76, 0x69, 0x0a, 0x16, 0x2c, 0x03, 0xa5, 0x1b, 0xbb, 0x81, 0xff, 0xbf, 0xe6, 0xea,
    0xde, 0xad, 0xc1, 0xe0, 0x9c, 0x59, 0x17, 0xb0, 0x5e, 0x9e, 0x5e, 0xdf, 0x1d, 0x9f, 0xad, 0x6b,
    0x54, 0x30, 0x08, 0xeb, 0x18, 0xc8, 0x98, 0x5b, 0x0b, 0x61, 0x52, 0x10, 0xd0, 0x0a, 0xf0, 0x62,
    0xdb, 0x7b, 0xd0, 0x4a, 0xa9, 0xe1, 0xc5, 0x27, 0xfb, 0x32, 0xb6, 0xa8, 0x2b, 0x2e, 0x1b, 0x48,
    0x13, 0xa2, 0x21, 0x51, 0x3f, 0xe0, 0x7f, 0xdb, 0x3e, 0x0b, 0xea, 0xff, 0x67, 0xfb, 0x74, 0x79,
    0xf1, 0x2d, 0x4b, 0x1a, 0x4b, 0xfc, 0x35, 0x33, 0xf1, 0x67, 0x07, 0xba, 0x66, 0xfa, 0x45, 0x6e,
    0xa1, 0xa7, 0x35, 0xcb, 0x6f, 0x88, 0xaa, 0x9b, 0x15, 0x60, 0x59, 0x51, 0x3a, 0x5b, 0x2b, 0xd9,
    0x84, 0xa8, 0xec, 0xfe, 0x9f, 0xbd, 0x24, 0x31, 0x60, 0xfb, 0x5b, 0x6e, 0x91, 0x02, 0x53, 0x7e,
    0x85, 0x47, 0x5c, 0x26, 0x5d, 0xec, 0x4f, 0x52, 0xde, 0xfb, 0x55, 0xd5, 0x10, 0x2e, 0x9e, 0x5d,
    0x87, 0xe4, 0xa4, 0x92, 0x08, 0x5d, 0xfc, 0x74, 0xad, 0xce, 0xe0, 0x00, 0xbb, 0x66, 0xdd, 0x70,
    0xd5, 0x52, 0x6e, 0x59, 0xdb, 0x31, 0x6e, 0xc8, 0x36, 0xaf, 0x4e, 0x7b, 0x3b, 0xb5, 0x52, 0x2a,
    0x34, 0xcf, 0x47, 0x2f, 0x23, 0x6e, 0xcb, 0xc3, 0x11, 0x79, 0xa9, 0x21, 0xf0, 0x70, 0xe3, 0xd9,
    0x28, 0x28, 0x8f, 0x4d, 0xde, 0xf3, 0x64, 0x07, 0x0c, 0x37, 0x17, 0x87, 0xfb, 0x45, 0x5d, 0xbb,
    0x22, 0x32, 0xc7, 0x9b, 0xe5, 0x3a, 0x31, 0xb8, 0xf3, 0xef, 0xe1, 0x01, 0xc5, 0x22, 0xd9, 0xe4,
    0x64, 0x6b, 0x76, 0x09, 0x24, 0xbe, 0x85, 0x65, 0x82, 0x21, 0xeb, 0x9c, 0xc6, 0xea, 0x7e, 0x9a,
    0x63, 0x1c, 0x24, 0xbe, 0x91, 0x97, 0x59, 0x31, 0x30, 0xf8, 0x7f, 0x9f, 0x89, 0xc9, 0xd2, 0x54,
    0x69, 0x2c, 0xf6, 0xeb, 0xeb, 0x44, 0xb3, 0x69, 0x43, 0x6c, 0xde, 0x39, 0xd2, 0x94, 0x2f, 0xf1,
    0x39, 0xe2, 0xe5, 0xc3, 0x35, 0xad, 0x92, 0xc8, 0xd2, 0xc8, 0x9d, 0x46, 0x0e, 0x2b, 0xc9, 0x76,
    0xd7, 0x62, 0xdb, 0x3b, 0x10, 0x2b, 0x89, 0xa3, 0x18, 0x4b, 0x91, 0x61, 0x14, 0x7e, 0xc7, 0x25,
    0xfb, 0xec, 0xe9, 0x6e, 0xa8, 0xdf, 0xf2, 0x07, 0x69, 0x24
};
#endif

PyTypeObject *init_Akonadi_EntityTreeModel(PyObject *enclosingClass)
{
    auto &typeStruct = SbkAkonadiCoreTypeStructs[SBK_Akonadi_EntityTreeModel_IDX];
    if (typeStruct.type != nullptr)
        return typeStruct.type;

    auto *base1 = reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QAbstractItemModel_IDX]));
    Shiboken::AutoDecRef Sbk_Akonadi_EntityTreeModel_Type_bases(PyTuple_Pack(1, base1));

    PyTypeObject *pyType = Shiboken::ObjectType::introduceWrapperType(
        enclosingClass,
        "EntityTreeModel",
        "Akonadi::EntityTreeModel*",
        &Sbk_Akonadi_EntityTreeModel_spec,
        &Shiboken::callCppDestructor< Akonadi::EntityTreeModel >,
        Sbk_Akonadi_EntityTreeModel_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::InnerClass);
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, Akonadi_EntityTreeModel_SignatureStrings);
#else
    InitSignatureBytes(pyType, Akonadi_EntityTreeModel_SignatureBytes, Akonadi_EntityTreeModel_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_Akonadi_EntityTreeModel_PropertyStrings);
    typeStruct.type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        EntityTreeModel_PythonToCpp_EntityTreeModel_PTR,
        is_EntityTreeModel_PythonToCpp_EntityTreeModel_PTR_Convertible,
        EntityTreeModel_PTR_CppToPython_EntityTreeModel);

    Shiboken::Conversions::registerConverterName(converter, "Akonadi::EntityTreeModel");
    Shiboken::Conversions::registerConverterName(converter, "Akonadi::EntityTreeModel*");
    Shiboken::Conversions::registerConverterName(converter, "Akonadi::EntityTreeModel&");
    Shiboken::Conversions::registerConverterAlias(converter, "EntityTreeModel");
    Shiboken::Conversions::registerConverterAlias(converter, "EntityTreeModel*");
    Shiboken::Conversions::registerConverterAlias(converter, "EntityTreeModel&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::Akonadi::EntityTreeModel).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(EntityTreeModelWrapper).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(pyType, &Sbk_Akonadi_EntityTreeModel_typeDiscovery);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_Akonadi_EntityTreeModel_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    [[maybe_unused]] PyTypeObject *EType{};

    // Initialization of enum 'Roles'.
    const char *Roles_Initializer[] = {
        "ItemIdRole",
        "ItemRole",
        "MimeTypeRole",
        "CollectionColorRole",
        "CollectionIdRole",
        "CollectionRole",
        "RemoteIdRole",
        "CollectionChildOrderRole",
        "ParentCollectionRole",
        "ColumnCountRole",
        "LoadedPartsRole",
        "AvailablePartsRole",
        "SessionRole",
        "CollectionRefRole",
        "CollectionDerefRole",
        "PendingCutRole",
        "EntityUrlRole",
        "UnreadCountRole",
        "FetchStateRole",
        "IsPopulatedRole",
        "OriginalCollectionNameRole",
        "DisplayNameRole",
        "UserRole",
        "TerminalUserRole",
        "EndRole",
        nullptr};
    // "uint16_t" used instead of "unsigned int"
    constexpr uint16_t Roles_InitializerValues[] = {
        uint16_t(Akonadi::EntityTreeModel::Roles::ItemIdRole),                 //  0x0101  257
        uint16_t(Akonadi::EntityTreeModel::Roles::ItemRole),                   //  0x0102  258
        uint16_t(Akonadi::EntityTreeModel::Roles::MimeTypeRole),               //  0x0103  259
        uint16_t(Akonadi::EntityTreeModel::Roles::CollectionColorRole),        //  0x0008  8
        uint16_t(Akonadi::EntityTreeModel::Roles::CollectionIdRole),           //  0x010a  266
        uint16_t(Akonadi::EntityTreeModel::Roles::CollectionRole),             //  0x010b  267
        uint16_t(Akonadi::EntityTreeModel::Roles::RemoteIdRole),               //  0x010c  268
        uint16_t(Akonadi::EntityTreeModel::Roles::CollectionChildOrderRole),   //  0x010d  269
        uint16_t(Akonadi::EntityTreeModel::Roles::ParentCollectionRole),       //  0x010e  270
        uint16_t(Akonadi::EntityTreeModel::Roles::ColumnCountRole),            //  0x010f  271
        uint16_t(Akonadi::EntityTreeModel::Roles::LoadedPartsRole),            //  0x0110  272
        uint16_t(Akonadi::EntityTreeModel::Roles::AvailablePartsRole),         //  0x0111  273
        uint16_t(Akonadi::EntityTreeModel::Roles::SessionRole),                //  0x0112  274
        uint16_t(Akonadi::EntityTreeModel::Roles::CollectionRefRole),          //  0x0113  275
        uint16_t(Akonadi::EntityTreeModel::Roles::CollectionDerefRole),        //  0x0114  276
        uint16_t(Akonadi::EntityTreeModel::Roles::PendingCutRole),             //  0x0115  277
        uint16_t(Akonadi::EntityTreeModel::Roles::EntityUrlRole),              //  0x0116  278
        uint16_t(Akonadi::EntityTreeModel::Roles::UnreadCountRole),            //  0x0117  279
        uint16_t(Akonadi::EntityTreeModel::Roles::FetchStateRole),             //  0x0118  280
        uint16_t(Akonadi::EntityTreeModel::Roles::IsPopulatedRole),            //  0x0119  281
        uint16_t(Akonadi::EntityTreeModel::Roles::OriginalCollectionNameRole), //  0x011a  282
        uint16_t(Akonadi::EntityTreeModel::Roles::DisplayNameRole),            //  0x011b  283
        uint16_t(Akonadi::EntityTreeModel::Roles::UserRole),                   //  0x02f4  756
        uint16_t(Akonadi::EntityTreeModel::Roles::TerminalUserRole),           //  0x07d0  2000
        uint16_t(Akonadi::EntityTreeModel::Roles::EndRole)                     //  0xffff  65535
        };
    EType = Shiboken::Enum::createPythonEnum(pyType,
        "1:AkonadiCore.Akonadi.EntityTreeModel.Roles",
        Roles_Initializer, Roles_InitializerValues);
    SbkAkonadiCoreTypeStructs[SBK_Akonadi_EntityTreeModel_Roles_IDX].type = EType;
    // Register converter for enum 'Akonadi::EntityTreeModel::Roles'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            Akonadi_EntityTreeModel_Roles_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_Akonadi_EntityTreeModel_Roles,
            is_Enum_PythonToCpp_Akonadi_EntityTreeModel_Roles_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "Akonadi::EntityTreeModel::Roles");
        Shiboken::Conversions::registerConverterAlias(converter, "EntityTreeModel::Roles");
        Shiboken::Conversions::registerConverterAlias(converter, "Roles");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'Roles' enum.

    // Initialization of enum 'FetchState'.
    const char *FetchState_Initializer[] = {
        "IdleState",
        "FetchingState",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t FetchState_InitializerValues[] = {
        uint8_t(Akonadi::EntityTreeModel::FetchState::IdleState),    //  0x00  0
        uint8_t(Akonadi::EntityTreeModel::FetchState::FetchingState) //  0x01  1
        };
    EType = Shiboken::Enum::createPythonEnum(pyType,
        "1:AkonadiCore.Akonadi.EntityTreeModel.FetchState",
        FetchState_Initializer, FetchState_InitializerValues);
    SbkAkonadiCoreTypeStructs[SBK_Akonadi_EntityTreeModel_FetchState_IDX].type = EType;
    // Register converter for enum 'Akonadi::EntityTreeModel::FetchState'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            Akonadi_EntityTreeModel_FetchState_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_Akonadi_EntityTreeModel_FetchState,
            is_Enum_PythonToCpp_Akonadi_EntityTreeModel_FetchState_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "Akonadi::EntityTreeModel::FetchState");
        Shiboken::Conversions::registerConverterAlias(converter, "EntityTreeModel::FetchState");
        Shiboken::Conversions::registerConverterAlias(converter, "FetchState");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'FetchState' enum.

    // Initialization of enum 'HeaderGroup'.
    const char *HeaderGroup_Initializer[] = {
        "EntityTreeHeaders",
        "CollectionTreeHeaders",
        "ItemListHeaders",
        "UserHeaders",
        "EndHeaderGroup",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t HeaderGroup_InitializerValues[] = {
        uint8_t(Akonadi::EntityTreeModel::HeaderGroup::EntityTreeHeaders),     //  0x00  0
        uint8_t(Akonadi::EntityTreeModel::HeaderGroup::CollectionTreeHeaders), //  0x01  1
        uint8_t(Akonadi::EntityTreeModel::HeaderGroup::ItemListHeaders),       //  0x02  2
        uint8_t(Akonadi::EntityTreeModel::HeaderGroup::UserHeaders),           //  0x0a  10
        uint8_t(Akonadi::EntityTreeModel::HeaderGroup::EndHeaderGroup)         //  0x20  32
        };
    EType = Shiboken::Enum::createPythonEnum(pyType,
        "1:AkonadiCore.Akonadi.EntityTreeModel.HeaderGroup",
        HeaderGroup_Initializer, HeaderGroup_InitializerValues);
    SbkAkonadiCoreTypeStructs[SBK_Akonadi_EntityTreeModel_HeaderGroup_IDX].type = EType;
    // Register converter for enum 'Akonadi::EntityTreeModel::HeaderGroup'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            Akonadi_EntityTreeModel_HeaderGroup_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_Akonadi_EntityTreeModel_HeaderGroup,
            is_Enum_PythonToCpp_Akonadi_EntityTreeModel_HeaderGroup_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "Akonadi::EntityTreeModel::HeaderGroup");
        Shiboken::Conversions::registerConverterAlias(converter, "EntityTreeModel::HeaderGroup");
        Shiboken::Conversions::registerConverterAlias(converter, "HeaderGroup");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'HeaderGroup' enum.

    // Initialization of enum 'ItemPopulationStrategy'.
    const char *ItemPopulationStrategy_Initializer[] = {
        "NoItemPopulation",
        "ImmediatePopulation",
        "LazyPopulation",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t ItemPopulationStrategy_InitializerValues[] = {
        uint8_t(Akonadi::EntityTreeModel::ItemPopulationStrategy::NoItemPopulation),    //  0x00  0
        uint8_t(Akonadi::EntityTreeModel::ItemPopulationStrategy::ImmediatePopulation), //  0x01  1
        uint8_t(Akonadi::EntityTreeModel::ItemPopulationStrategy::LazyPopulation)       //  0x02  2
        };
    EType = Shiboken::Enum::createPythonEnum(pyType,
        "1:AkonadiCore.Akonadi.EntityTreeModel.ItemPopulationStrategy",
        ItemPopulationStrategy_Initializer, ItemPopulationStrategy_InitializerValues);
    SbkAkonadiCoreTypeStructs[SBK_Akonadi_EntityTreeModel_ItemPopulationStrategy_IDX].type = EType;
    // Register converter for enum 'Akonadi::EntityTreeModel::ItemPopulationStrategy'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            Akonadi_EntityTreeModel_ItemPopulationStrategy_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_Akonadi_EntityTreeModel_ItemPopulationStrategy,
            is_Enum_PythonToCpp_Akonadi_EntityTreeModel_ItemPopulationStrategy_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "Akonadi::EntityTreeModel::ItemPopulationStrategy");
        Shiboken::Conversions::registerConverterAlias(converter, "EntityTreeModel::ItemPopulationStrategy");
        Shiboken::Conversions::registerConverterAlias(converter, "ItemPopulationStrategy");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'ItemPopulationStrategy' enum.

    // Initialization of enum 'CollectionFetchStrategy'.
    const char *CollectionFetchStrategy_Initializer[] = {
        "FetchNoCollections",
        "FetchFirstLevelChildCollections",
        "FetchCollectionsRecursive",
        "FetchCollectionsMerged",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t CollectionFetchStrategy_InitializerValues[] = {
        uint8_t(Akonadi::EntityTreeModel::CollectionFetchStrategy::FetchNoCollections),              //  0x00  0
        uint8_t(Akonadi::EntityTreeModel::CollectionFetchStrategy::FetchFirstLevelChildCollections), //  0x01  1
        uint8_t(Akonadi::EntityTreeModel::CollectionFetchStrategy::FetchCollectionsRecursive),       //  0x02  2
        uint8_t(Akonadi::EntityTreeModel::CollectionFetchStrategy::FetchCollectionsMerged)           //  0x03  3
        };
    EType = Shiboken::Enum::createPythonEnum(pyType,
        "1:AkonadiCore.Akonadi.EntityTreeModel.CollectionFetchStrategy",
        CollectionFetchStrategy_Initializer, CollectionFetchStrategy_InitializerValues);
    SbkAkonadiCoreTypeStructs[SBK_Akonadi_EntityTreeModel_CollectionFetchStrategy_IDX].type = EType;
    // Register converter for enum 'Akonadi::EntityTreeModel::CollectionFetchStrategy'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            Akonadi_EntityTreeModel_CollectionFetchStrategy_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_Akonadi_EntityTreeModel_CollectionFetchStrategy,
            is_Enum_PythonToCpp_Akonadi_EntityTreeModel_CollectionFetchStrategy_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "Akonadi::EntityTreeModel::CollectionFetchStrategy");
        Shiboken::Conversions::registerConverterAlias(converter, "EntityTreeModel::CollectionFetchStrategy");
        Shiboken::Conversions::registerConverterAlias(converter, "CollectionFetchStrategy");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'CollectionFetchStrategy' enum.

    PySide::Signal::registerSignals(pyType, &::Akonadi::EntityTreeModel::staticMetaObject);
    qRegisterMetaType< ::Akonadi::EntityTreeModel::Roles >("EntityTreeModel::Roles");
    qRegisterMetaType< ::Akonadi::EntityTreeModel::Roles >("Akonadi::EntityTreeModel::Roles");
    qRegisterMetaType< ::Akonadi::EntityTreeModel::FetchState >("EntityTreeModel::FetchState");
    qRegisterMetaType< ::Akonadi::EntityTreeModel::FetchState >("Akonadi::EntityTreeModel::FetchState");
    qRegisterMetaType< ::Akonadi::EntityTreeModel::HeaderGroup >("EntityTreeModel::HeaderGroup");
    qRegisterMetaType< ::Akonadi::EntityTreeModel::HeaderGroup >("Akonadi::EntityTreeModel::HeaderGroup");
    qRegisterMetaType< ::Akonadi::EntityTreeModel::ItemPopulationStrategy >("EntityTreeModel::ItemPopulationStrategy");
    qRegisterMetaType< ::Akonadi::EntityTreeModel::ItemPopulationStrategy >("Akonadi::EntityTreeModel::ItemPopulationStrategy");
    qRegisterMetaType< ::Akonadi::EntityTreeModel::CollectionFetchStrategy >("EntityTreeModel::CollectionFetchStrategy");
    qRegisterMetaType< ::Akonadi::EntityTreeModel::CollectionFetchStrategy >("Akonadi::EntityTreeModel::CollectionFetchStrategy");
    Shiboken::ObjectType::setSubTypeInitHook(pyType, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(pyType, &::Akonadi::EntityTreeModel::staticMetaObject, sizeof(EntityTreeModelWrapper));

    return pyType;
}
